from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.table_comparison_column_count_match_check_spec import (
        TableComparisonColumnCountMatchCheckSpec,
    )
    from ..models.table_comparison_daily_monitoring_checks_spec_custom_checks import (
        TableComparisonDailyMonitoringChecksSpecCustomChecks,
    )
    from ..models.table_comparison_row_count_match_check_spec import (
        TableComparisonRowCountMatchCheckSpec,
    )


T = TypeVar("T", bound="TableComparisonDailyMonitoringChecksSpec")


@_attrs_define
class TableComparisonDailyMonitoringChecksSpec:
    """
    Attributes:
        custom_checks (Union[Unset, TableComparisonDailyMonitoringChecksSpecCustomChecks]): Dictionary of additional
            custom checks within this category. The keys are check names defined in the definition section. The sensor
            parameters and rules should match the type of the configured sensor and rule for the custom check.
        daily_row_count_match (Union[Unset, TableComparisonRowCountMatchCheckSpec]):
        daily_column_count_match (Union[Unset, TableComparisonColumnCountMatchCheckSpec]):
    """

    custom_checks: Union[
        Unset, "TableComparisonDailyMonitoringChecksSpecCustomChecks"
    ] = UNSET
    daily_row_count_match: Union[Unset, "TableComparisonRowCountMatchCheckSpec"] = UNSET
    daily_column_count_match: Union[
        Unset, "TableComparisonColumnCountMatchCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        custom_checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom_checks, Unset):
            custom_checks = self.custom_checks.to_dict()

        daily_row_count_match: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_row_count_match, Unset):
            daily_row_count_match = self.daily_row_count_match.to_dict()

        daily_column_count_match: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_column_count_match, Unset):
            daily_column_count_match = self.daily_column_count_match.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if custom_checks is not UNSET:
            field_dict["custom_checks"] = custom_checks
        if daily_row_count_match is not UNSET:
            field_dict["daily_row_count_match"] = daily_row_count_match
        if daily_column_count_match is not UNSET:
            field_dict["daily_column_count_match"] = daily_column_count_match

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.table_comparison_column_count_match_check_spec import (
            TableComparisonColumnCountMatchCheckSpec,
        )
        from ..models.table_comparison_daily_monitoring_checks_spec_custom_checks import (
            TableComparisonDailyMonitoringChecksSpecCustomChecks,
        )
        from ..models.table_comparison_row_count_match_check_spec import (
            TableComparisonRowCountMatchCheckSpec,
        )

        d = src_dict.copy()
        _custom_checks = d.pop("custom_checks", UNSET)
        custom_checks: Union[
            Unset, TableComparisonDailyMonitoringChecksSpecCustomChecks
        ]
        if isinstance(_custom_checks, Unset):
            custom_checks = UNSET
        else:
            custom_checks = (
                TableComparisonDailyMonitoringChecksSpecCustomChecks.from_dict(
                    _custom_checks
                )
            )

        _daily_row_count_match = d.pop("daily_row_count_match", UNSET)
        daily_row_count_match: Union[Unset, TableComparisonRowCountMatchCheckSpec]
        if isinstance(_daily_row_count_match, Unset):
            daily_row_count_match = UNSET
        else:
            daily_row_count_match = TableComparisonRowCountMatchCheckSpec.from_dict(
                _daily_row_count_match
            )

        _daily_column_count_match = d.pop("daily_column_count_match", UNSET)
        daily_column_count_match: Union[Unset, TableComparisonColumnCountMatchCheckSpec]
        if isinstance(_daily_column_count_match, Unset):
            daily_column_count_match = UNSET
        else:
            daily_column_count_match = (
                TableComparisonColumnCountMatchCheckSpec.from_dict(
                    _daily_column_count_match
                )
            )

        table_comparison_daily_monitoring_checks_spec = cls(
            custom_checks=custom_checks,
            daily_row_count_match=daily_row_count_match,
            daily_column_count_match=daily_column_count_match,
        )

        table_comparison_daily_monitoring_checks_spec.additional_properties = d
        return table_comparison_daily_monitoring_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.table_accuracy_monthly_monitoring_checks_spec import (
        TableAccuracyMonthlyMonitoringChecksSpec,
    )
    from ..models.table_availability_monthly_monitoring_checks_spec import (
        TableAvailabilityMonthlyMonitoringChecksSpec,
    )
    from ..models.table_custom_sql_monthly_monitoring_checks_spec import (
        TableCustomSqlMonthlyMonitoringChecksSpec,
    )
    from ..models.table_monthly_monitoring_check_categories_spec_comparisons import (
        TableMonthlyMonitoringCheckCategoriesSpecComparisons,
    )
    from ..models.table_monthly_monitoring_check_categories_spec_custom import (
        TableMonthlyMonitoringCheckCategoriesSpecCustom,
    )
    from ..models.table_schema_monthly_monitoring_checks_spec import (
        TableSchemaMonthlyMonitoringChecksSpec,
    )
    from ..models.table_timeliness_monthly_monitoring_checks_spec import (
        TableTimelinessMonthlyMonitoringChecksSpec,
    )
    from ..models.table_volume_monthly_monitoring_checks_spec import (
        TableVolumeMonthlyMonitoringChecksSpec,
    )


T = TypeVar("T", bound="TableMonthlyMonitoringCheckCategoriesSpec")


@_attrs_define
class TableMonthlyMonitoringCheckCategoriesSpec:
    """
    Attributes:
        custom (Union[Unset, TableMonthlyMonitoringCheckCategoriesSpecCustom]): Dictionary of custom checks. The keys
            are check names within this category.
        volume (Union[Unset, TableVolumeMonthlyMonitoringChecksSpec]):
        timeliness (Union[Unset, TableTimelinessMonthlyMonitoringChecksSpec]):
        accuracy (Union[Unset, TableAccuracyMonthlyMonitoringChecksSpec]):
        custom_sql (Union[Unset, TableCustomSqlMonthlyMonitoringChecksSpec]):
        availability (Union[Unset, TableAvailabilityMonthlyMonitoringChecksSpec]):
        schema (Union[Unset, TableSchemaMonthlyMonitoringChecksSpec]):
        comparisons (Union[Unset, TableMonthlyMonitoringCheckCategoriesSpecComparisons]): Dictionary of configuration of
            checks for table comparisons. The key that identifies each comparison must match the name of a data comparison
            that is configured on the parent table.
    """

    custom: Union[Unset, "TableMonthlyMonitoringCheckCategoriesSpecCustom"] = UNSET
    volume: Union[Unset, "TableVolumeMonthlyMonitoringChecksSpec"] = UNSET
    timeliness: Union[Unset, "TableTimelinessMonthlyMonitoringChecksSpec"] = UNSET
    accuracy: Union[Unset, "TableAccuracyMonthlyMonitoringChecksSpec"] = UNSET
    custom_sql: Union[Unset, "TableCustomSqlMonthlyMonitoringChecksSpec"] = UNSET
    availability: Union[Unset, "TableAvailabilityMonthlyMonitoringChecksSpec"] = UNSET
    schema: Union[Unset, "TableSchemaMonthlyMonitoringChecksSpec"] = UNSET
    comparisons: Union[
        Unset, "TableMonthlyMonitoringCheckCategoriesSpecComparisons"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        custom: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom, Unset):
            custom = self.custom.to_dict()

        volume: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.volume, Unset):
            volume = self.volume.to_dict()

        timeliness: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.timeliness, Unset):
            timeliness = self.timeliness.to_dict()

        accuracy: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.accuracy, Unset):
            accuracy = self.accuracy.to_dict()

        custom_sql: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom_sql, Unset):
            custom_sql = self.custom_sql.to_dict()

        availability: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.availability, Unset):
            availability = self.availability.to_dict()

        schema: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.schema, Unset):
            schema = self.schema.to_dict()

        comparisons: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.comparisons, Unset):
            comparisons = self.comparisons.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if custom is not UNSET:
            field_dict["custom"] = custom
        if volume is not UNSET:
            field_dict["volume"] = volume
        if timeliness is not UNSET:
            field_dict["timeliness"] = timeliness
        if accuracy is not UNSET:
            field_dict["accuracy"] = accuracy
        if custom_sql is not UNSET:
            field_dict["custom_sql"] = custom_sql
        if availability is not UNSET:
            field_dict["availability"] = availability
        if schema is not UNSET:
            field_dict["schema"] = schema
        if comparisons is not UNSET:
            field_dict["comparisons"] = comparisons

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.table_accuracy_monthly_monitoring_checks_spec import (
            TableAccuracyMonthlyMonitoringChecksSpec,
        )
        from ..models.table_availability_monthly_monitoring_checks_spec import (
            TableAvailabilityMonthlyMonitoringChecksSpec,
        )
        from ..models.table_custom_sql_monthly_monitoring_checks_spec import (
            TableCustomSqlMonthlyMonitoringChecksSpec,
        )
        from ..models.table_monthly_monitoring_check_categories_spec_comparisons import (
            TableMonthlyMonitoringCheckCategoriesSpecComparisons,
        )
        from ..models.table_monthly_monitoring_check_categories_spec_custom import (
            TableMonthlyMonitoringCheckCategoriesSpecCustom,
        )
        from ..models.table_schema_monthly_monitoring_checks_spec import (
            TableSchemaMonthlyMonitoringChecksSpec,
        )
        from ..models.table_timeliness_monthly_monitoring_checks_spec import (
            TableTimelinessMonthlyMonitoringChecksSpec,
        )
        from ..models.table_volume_monthly_monitoring_checks_spec import (
            TableVolumeMonthlyMonitoringChecksSpec,
        )

        d = src_dict.copy()
        _custom = d.pop("custom", UNSET)
        custom: Union[Unset, TableMonthlyMonitoringCheckCategoriesSpecCustom]
        if isinstance(_custom, Unset):
            custom = UNSET
        else:
            custom = TableMonthlyMonitoringCheckCategoriesSpecCustom.from_dict(_custom)

        _volume = d.pop("volume", UNSET)
        volume: Union[Unset, TableVolumeMonthlyMonitoringChecksSpec]
        if isinstance(_volume, Unset):
            volume = UNSET
        else:
            volume = TableVolumeMonthlyMonitoringChecksSpec.from_dict(_volume)

        _timeliness = d.pop("timeliness", UNSET)
        timeliness: Union[Unset, TableTimelinessMonthlyMonitoringChecksSpec]
        if isinstance(_timeliness, Unset):
            timeliness = UNSET
        else:
            timeliness = TableTimelinessMonthlyMonitoringChecksSpec.from_dict(
                _timeliness
            )

        _accuracy = d.pop("accuracy", UNSET)
        accuracy: Union[Unset, TableAccuracyMonthlyMonitoringChecksSpec]
        if isinstance(_accuracy, Unset):
            accuracy = UNSET
        else:
            accuracy = TableAccuracyMonthlyMonitoringChecksSpec.from_dict(_accuracy)

        _custom_sql = d.pop("custom_sql", UNSET)
        custom_sql: Union[Unset, TableCustomSqlMonthlyMonitoringChecksSpec]
        if isinstance(_custom_sql, Unset):
            custom_sql = UNSET
        else:
            custom_sql = TableCustomSqlMonthlyMonitoringChecksSpec.from_dict(
                _custom_sql
            )

        _availability = d.pop("availability", UNSET)
        availability: Union[Unset, TableAvailabilityMonthlyMonitoringChecksSpec]
        if isinstance(_availability, Unset):
            availability = UNSET
        else:
            availability = TableAvailabilityMonthlyMonitoringChecksSpec.from_dict(
                _availability
            )

        _schema = d.pop("schema", UNSET)
        schema: Union[Unset, TableSchemaMonthlyMonitoringChecksSpec]
        if isinstance(_schema, Unset):
            schema = UNSET
        else:
            schema = TableSchemaMonthlyMonitoringChecksSpec.from_dict(_schema)

        _comparisons = d.pop("comparisons", UNSET)
        comparisons: Union[Unset, TableMonthlyMonitoringCheckCategoriesSpecComparisons]
        if isinstance(_comparisons, Unset):
            comparisons = UNSET
        else:
            comparisons = (
                TableMonthlyMonitoringCheckCategoriesSpecComparisons.from_dict(
                    _comparisons
                )
            )

        table_monthly_monitoring_check_categories_spec = cls(
            custom=custom,
            volume=volume,
            timeliness=timeliness,
            accuracy=accuracy,
            custom_sql=custom_sql,
            availability=availability,
            schema=schema,
            comparisons=comparisons,
        )

        table_monthly_monitoring_check_categories_spec.additional_properties = d
        return table_monthly_monitoring_check_categories_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_accepted_values_monthly_monitoring_checks_spec import (
        ColumnAcceptedValuesMonthlyMonitoringChecksSpec,
    )
    from ..models.column_accuracy_monthly_monitoring_checks_spec import (
        ColumnAccuracyMonthlyMonitoringChecksSpec,
    )
    from ..models.column_anomaly_monthly_monitoring_checks_spec import (
        ColumnAnomalyMonthlyMonitoringChecksSpec,
    )
    from ..models.column_blanks_monthly_monitoring_checks_spec import (
        ColumnBlanksMonthlyMonitoringChecksSpec,
    )
    from ..models.column_bool_monthly_monitoring_checks_spec import (
        ColumnBoolMonthlyMonitoringChecksSpec,
    )
    from ..models.column_custom_sql_monthly_monitoring_checks_spec import (
        ColumnCustomSqlMonthlyMonitoringChecksSpec,
    )
    from ..models.column_datatype_monthly_monitoring_checks_spec import (
        ColumnDatatypeMonthlyMonitoringChecksSpec,
    )
    from ..models.column_datetime_monthly_monitoring_checks_spec import (
        ColumnDatetimeMonthlyMonitoringChecksSpec,
    )
    from ..models.column_integrity_monthly_monitoring_checks_spec import (
        ColumnIntegrityMonthlyMonitoringChecksSpec,
    )
    from ..models.column_monthly_monitoring_check_categories_spec_comparisons import (
        ColumnMonthlyMonitoringCheckCategoriesSpecComparisons,
    )
    from ..models.column_monthly_monitoring_check_categories_spec_custom import (
        ColumnMonthlyMonitoringCheckCategoriesSpecCustom,
    )
    from ..models.column_nulls_monthly_monitoring_checks_spec import (
        ColumnNullsMonthlyMonitoringChecksSpec,
    )
    from ..models.column_numeric_monthly_monitoring_checks_spec import (
        ColumnNumericMonthlyMonitoringChecksSpec,
    )
    from ..models.column_patterns_monthly_monitoring_checks_spec import (
        ColumnPatternsMonthlyMonitoringChecksSpec,
    )
    from ..models.column_pii_monthly_monitoring_checks_spec import (
        ColumnPiiMonthlyMonitoringChecksSpec,
    )
    from ..models.column_schema_monthly_monitoring_checks_spec import (
        ColumnSchemaMonthlyMonitoringChecksSpec,
    )
    from ..models.column_text_monthly_monitoring_checks_spec import (
        ColumnTextMonthlyMonitoringChecksSpec,
    )
    from ..models.column_uniqueness_monthly_monitoring_checks_spec import (
        ColumnUniquenessMonthlyMonitoringChecksSpec,
    )


T = TypeVar("T", bound="ColumnMonthlyMonitoringCheckCategoriesSpec")


@_attrs_define
class ColumnMonthlyMonitoringCheckCategoriesSpec:
    """
    Attributes:
        custom (Union[Unset, ColumnMonthlyMonitoringCheckCategoriesSpecCustom]): Dictionary of custom checks. The keys
            are check names within this category.
        nulls (Union[Unset, ColumnNullsMonthlyMonitoringChecksSpec]):
        uniqueness (Union[Unset, ColumnUniquenessMonthlyMonitoringChecksSpec]):
        accepted_values (Union[Unset, ColumnAcceptedValuesMonthlyMonitoringChecksSpec]):
        text (Union[Unset, ColumnTextMonthlyMonitoringChecksSpec]):
        blanks (Union[Unset, ColumnBlanksMonthlyMonitoringChecksSpec]):
        patterns (Union[Unset, ColumnPatternsMonthlyMonitoringChecksSpec]):
        pii (Union[Unset, ColumnPiiMonthlyMonitoringChecksSpec]):
        numeric (Union[Unset, ColumnNumericMonthlyMonitoringChecksSpec]):
        anomaly (Union[Unset, ColumnAnomalyMonthlyMonitoringChecksSpec]):
        datetime_ (Union[Unset, ColumnDatetimeMonthlyMonitoringChecksSpec]):
        bool_ (Union[Unset, ColumnBoolMonthlyMonitoringChecksSpec]):
        integrity (Union[Unset, ColumnIntegrityMonthlyMonitoringChecksSpec]):
        accuracy (Union[Unset, ColumnAccuracyMonthlyMonitoringChecksSpec]):
        custom_sql (Union[Unset, ColumnCustomSqlMonthlyMonitoringChecksSpec]):
        datatype (Union[Unset, ColumnDatatypeMonthlyMonitoringChecksSpec]):
        schema (Union[Unset, ColumnSchemaMonthlyMonitoringChecksSpec]):
        comparisons (Union[Unset, ColumnMonthlyMonitoringCheckCategoriesSpecComparisons]): Dictionary of configuration
            of checks for table comparisons at a column level. The key that identifies each comparison must match the name
            of a data comparison that is configured on the parent table.
    """

    custom: Union[Unset, "ColumnMonthlyMonitoringCheckCategoriesSpecCustom"] = UNSET
    nulls: Union[Unset, "ColumnNullsMonthlyMonitoringChecksSpec"] = UNSET
    uniqueness: Union[Unset, "ColumnUniquenessMonthlyMonitoringChecksSpec"] = UNSET
    accepted_values: Union[
        Unset, "ColumnAcceptedValuesMonthlyMonitoringChecksSpec"
    ] = UNSET
    text: Union[Unset, "ColumnTextMonthlyMonitoringChecksSpec"] = UNSET
    blanks: Union[Unset, "ColumnBlanksMonthlyMonitoringChecksSpec"] = UNSET
    patterns: Union[Unset, "ColumnPatternsMonthlyMonitoringChecksSpec"] = UNSET
    pii: Union[Unset, "ColumnPiiMonthlyMonitoringChecksSpec"] = UNSET
    numeric: Union[Unset, "ColumnNumericMonthlyMonitoringChecksSpec"] = UNSET
    anomaly: Union[Unset, "ColumnAnomalyMonthlyMonitoringChecksSpec"] = UNSET
    datetime_: Union[Unset, "ColumnDatetimeMonthlyMonitoringChecksSpec"] = UNSET
    bool_: Union[Unset, "ColumnBoolMonthlyMonitoringChecksSpec"] = UNSET
    integrity: Union[Unset, "ColumnIntegrityMonthlyMonitoringChecksSpec"] = UNSET
    accuracy: Union[Unset, "ColumnAccuracyMonthlyMonitoringChecksSpec"] = UNSET
    custom_sql: Union[Unset, "ColumnCustomSqlMonthlyMonitoringChecksSpec"] = UNSET
    datatype: Union[Unset, "ColumnDatatypeMonthlyMonitoringChecksSpec"] = UNSET
    schema: Union[Unset, "ColumnSchemaMonthlyMonitoringChecksSpec"] = UNSET
    comparisons: Union[
        Unset, "ColumnMonthlyMonitoringCheckCategoriesSpecComparisons"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        custom: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom, Unset):
            custom = self.custom.to_dict()

        nulls: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.nulls, Unset):
            nulls = self.nulls.to_dict()

        uniqueness: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.uniqueness, Unset):
            uniqueness = self.uniqueness.to_dict()

        accepted_values: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.accepted_values, Unset):
            accepted_values = self.accepted_values.to_dict()

        text: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.text, Unset):
            text = self.text.to_dict()

        blanks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.blanks, Unset):
            blanks = self.blanks.to_dict()

        patterns: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.patterns, Unset):
            patterns = self.patterns.to_dict()

        pii: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.pii, Unset):
            pii = self.pii.to_dict()

        numeric: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.numeric, Unset):
            numeric = self.numeric.to_dict()

        anomaly: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.anomaly, Unset):
            anomaly = self.anomaly.to_dict()

        datetime_: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.datetime_, Unset):
            datetime_ = self.datetime_.to_dict()

        bool_: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.bool_, Unset):
            bool_ = self.bool_.to_dict()

        integrity: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.integrity, Unset):
            integrity = self.integrity.to_dict()

        accuracy: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.accuracy, Unset):
            accuracy = self.accuracy.to_dict()

        custom_sql: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom_sql, Unset):
            custom_sql = self.custom_sql.to_dict()

        datatype: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.datatype, Unset):
            datatype = self.datatype.to_dict()

        schema: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.schema, Unset):
            schema = self.schema.to_dict()

        comparisons: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.comparisons, Unset):
            comparisons = self.comparisons.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if custom is not UNSET:
            field_dict["custom"] = custom
        if nulls is not UNSET:
            field_dict["nulls"] = nulls
        if uniqueness is not UNSET:
            field_dict["uniqueness"] = uniqueness
        if accepted_values is not UNSET:
            field_dict["accepted_values"] = accepted_values
        if text is not UNSET:
            field_dict["text"] = text
        if blanks is not UNSET:
            field_dict["blanks"] = blanks
        if patterns is not UNSET:
            field_dict["patterns"] = patterns
        if pii is not UNSET:
            field_dict["pii"] = pii
        if numeric is not UNSET:
            field_dict["numeric"] = numeric
        if anomaly is not UNSET:
            field_dict["anomaly"] = anomaly
        if datetime_ is not UNSET:
            field_dict["datetime"] = datetime_
        if bool_ is not UNSET:
            field_dict["bool"] = bool_
        if integrity is not UNSET:
            field_dict["integrity"] = integrity
        if accuracy is not UNSET:
            field_dict["accuracy"] = accuracy
        if custom_sql is not UNSET:
            field_dict["custom_sql"] = custom_sql
        if datatype is not UNSET:
            field_dict["datatype"] = datatype
        if schema is not UNSET:
            field_dict["schema"] = schema
        if comparisons is not UNSET:
            field_dict["comparisons"] = comparisons

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_accepted_values_monthly_monitoring_checks_spec import (
            ColumnAcceptedValuesMonthlyMonitoringChecksSpec,
        )
        from ..models.column_accuracy_monthly_monitoring_checks_spec import (
            ColumnAccuracyMonthlyMonitoringChecksSpec,
        )
        from ..models.column_anomaly_monthly_monitoring_checks_spec import (
            ColumnAnomalyMonthlyMonitoringChecksSpec,
        )
        from ..models.column_blanks_monthly_monitoring_checks_spec import (
            ColumnBlanksMonthlyMonitoringChecksSpec,
        )
        from ..models.column_bool_monthly_monitoring_checks_spec import (
            ColumnBoolMonthlyMonitoringChecksSpec,
        )
        from ..models.column_custom_sql_monthly_monitoring_checks_spec import (
            ColumnCustomSqlMonthlyMonitoringChecksSpec,
        )
        from ..models.column_datatype_monthly_monitoring_checks_spec import (
            ColumnDatatypeMonthlyMonitoringChecksSpec,
        )
        from ..models.column_datetime_monthly_monitoring_checks_spec import (
            ColumnDatetimeMonthlyMonitoringChecksSpec,
        )
        from ..models.column_integrity_monthly_monitoring_checks_spec import (
            ColumnIntegrityMonthlyMonitoringChecksSpec,
        )
        from ..models.column_monthly_monitoring_check_categories_spec_comparisons import (
            ColumnMonthlyMonitoringCheckCategoriesSpecComparisons,
        )
        from ..models.column_monthly_monitoring_check_categories_spec_custom import (
            ColumnMonthlyMonitoringCheckCategoriesSpecCustom,
        )
        from ..models.column_nulls_monthly_monitoring_checks_spec import (
            ColumnNullsMonthlyMonitoringChecksSpec,
        )
        from ..models.column_numeric_monthly_monitoring_checks_spec import (
            ColumnNumericMonthlyMonitoringChecksSpec,
        )
        from ..models.column_patterns_monthly_monitoring_checks_spec import (
            ColumnPatternsMonthlyMonitoringChecksSpec,
        )
        from ..models.column_pii_monthly_monitoring_checks_spec import (
            ColumnPiiMonthlyMonitoringChecksSpec,
        )
        from ..models.column_schema_monthly_monitoring_checks_spec import (
            ColumnSchemaMonthlyMonitoringChecksSpec,
        )
        from ..models.column_text_monthly_monitoring_checks_spec import (
            ColumnTextMonthlyMonitoringChecksSpec,
        )
        from ..models.column_uniqueness_monthly_monitoring_checks_spec import (
            ColumnUniquenessMonthlyMonitoringChecksSpec,
        )

        d = src_dict.copy()
        _custom = d.pop("custom", UNSET)
        custom: Union[Unset, ColumnMonthlyMonitoringCheckCategoriesSpecCustom]
        if isinstance(_custom, Unset):
            custom = UNSET
        else:
            custom = ColumnMonthlyMonitoringCheckCategoriesSpecCustom.from_dict(_custom)

        _nulls = d.pop("nulls", UNSET)
        nulls: Union[Unset, ColumnNullsMonthlyMonitoringChecksSpec]
        if isinstance(_nulls, Unset):
            nulls = UNSET
        else:
            nulls = ColumnNullsMonthlyMonitoringChecksSpec.from_dict(_nulls)

        _uniqueness = d.pop("uniqueness", UNSET)
        uniqueness: Union[Unset, ColumnUniquenessMonthlyMonitoringChecksSpec]
        if isinstance(_uniqueness, Unset):
            uniqueness = UNSET
        else:
            uniqueness = ColumnUniquenessMonthlyMonitoringChecksSpec.from_dict(
                _uniqueness
            )

        _accepted_values = d.pop("accepted_values", UNSET)
        accepted_values: Union[Unset, ColumnAcceptedValuesMonthlyMonitoringChecksSpec]
        if isinstance(_accepted_values, Unset):
            accepted_values = UNSET
        else:
            accepted_values = ColumnAcceptedValuesMonthlyMonitoringChecksSpec.from_dict(
                _accepted_values
            )

        _text = d.pop("text", UNSET)
        text: Union[Unset, ColumnTextMonthlyMonitoringChecksSpec]
        if isinstance(_text, Unset):
            text = UNSET
        else:
            text = ColumnTextMonthlyMonitoringChecksSpec.from_dict(_text)

        _blanks = d.pop("blanks", UNSET)
        blanks: Union[Unset, ColumnBlanksMonthlyMonitoringChecksSpec]
        if isinstance(_blanks, Unset):
            blanks = UNSET
        else:
            blanks = ColumnBlanksMonthlyMonitoringChecksSpec.from_dict(_blanks)

        _patterns = d.pop("patterns", UNSET)
        patterns: Union[Unset, ColumnPatternsMonthlyMonitoringChecksSpec]
        if isinstance(_patterns, Unset):
            patterns = UNSET
        else:
            patterns = ColumnPatternsMonthlyMonitoringChecksSpec.from_dict(_patterns)

        _pii = d.pop("pii", UNSET)
        pii: Union[Unset, ColumnPiiMonthlyMonitoringChecksSpec]
        if isinstance(_pii, Unset):
            pii = UNSET
        else:
            pii = ColumnPiiMonthlyMonitoringChecksSpec.from_dict(_pii)

        _numeric = d.pop("numeric", UNSET)
        numeric: Union[Unset, ColumnNumericMonthlyMonitoringChecksSpec]
        if isinstance(_numeric, Unset):
            numeric = UNSET
        else:
            numeric = ColumnNumericMonthlyMonitoringChecksSpec.from_dict(_numeric)

        _anomaly = d.pop("anomaly", UNSET)
        anomaly: Union[Unset, ColumnAnomalyMonthlyMonitoringChecksSpec]
        if isinstance(_anomaly, Unset):
            anomaly = UNSET
        else:
            anomaly = ColumnAnomalyMonthlyMonitoringChecksSpec.from_dict(_anomaly)

        _datetime_ = d.pop("datetime", UNSET)
        datetime_: Union[Unset, ColumnDatetimeMonthlyMonitoringChecksSpec]
        if isinstance(_datetime_, Unset):
            datetime_ = UNSET
        else:
            datetime_ = ColumnDatetimeMonthlyMonitoringChecksSpec.from_dict(_datetime_)

        _bool_ = d.pop("bool", UNSET)
        bool_: Union[Unset, ColumnBoolMonthlyMonitoringChecksSpec]
        if isinstance(_bool_, Unset):
            bool_ = UNSET
        else:
            bool_ = ColumnBoolMonthlyMonitoringChecksSpec.from_dict(_bool_)

        _integrity = d.pop("integrity", UNSET)
        integrity: Union[Unset, ColumnIntegrityMonthlyMonitoringChecksSpec]
        if isinstance(_integrity, Unset):
            integrity = UNSET
        else:
            integrity = ColumnIntegrityMonthlyMonitoringChecksSpec.from_dict(_integrity)

        _accuracy = d.pop("accuracy", UNSET)
        accuracy: Union[Unset, ColumnAccuracyMonthlyMonitoringChecksSpec]
        if isinstance(_accuracy, Unset):
            accuracy = UNSET
        else:
            accuracy = ColumnAccuracyMonthlyMonitoringChecksSpec.from_dict(_accuracy)

        _custom_sql = d.pop("custom_sql", UNSET)
        custom_sql: Union[Unset, ColumnCustomSqlMonthlyMonitoringChecksSpec]
        if isinstance(_custom_sql, Unset):
            custom_sql = UNSET
        else:
            custom_sql = ColumnCustomSqlMonthlyMonitoringChecksSpec.from_dict(
                _custom_sql
            )

        _datatype = d.pop("datatype", UNSET)
        datatype: Union[Unset, ColumnDatatypeMonthlyMonitoringChecksSpec]
        if isinstance(_datatype, Unset):
            datatype = UNSET
        else:
            datatype = ColumnDatatypeMonthlyMonitoringChecksSpec.from_dict(_datatype)

        _schema = d.pop("schema", UNSET)
        schema: Union[Unset, ColumnSchemaMonthlyMonitoringChecksSpec]
        if isinstance(_schema, Unset):
            schema = UNSET
        else:
            schema = ColumnSchemaMonthlyMonitoringChecksSpec.from_dict(_schema)

        _comparisons = d.pop("comparisons", UNSET)
        comparisons: Union[Unset, ColumnMonthlyMonitoringCheckCategoriesSpecComparisons]
        if isinstance(_comparisons, Unset):
            comparisons = UNSET
        else:
            comparisons = (
                ColumnMonthlyMonitoringCheckCategoriesSpecComparisons.from_dict(
                    _comparisons
                )
            )

        column_monthly_monitoring_check_categories_spec = cls(
            custom=custom,
            nulls=nulls,
            uniqueness=uniqueness,
            accepted_values=accepted_values,
            text=text,
            blanks=blanks,
            patterns=patterns,
            pii=pii,
            numeric=numeric,
            anomaly=anomaly,
            datetime_=datetime_,
            bool_=bool_,
            integrity=integrity,
            accuracy=accuracy,
            custom_sql=custom_sql,
            datatype=datatype,
            schema=schema,
            comparisons=comparisons,
        )

        column_monthly_monitoring_check_categories_spec.additional_properties = d
        return column_monthly_monitoring_check_categories_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar(
    "T", bound="ColumnAccuracyTotalNotNullCountMatchPercentSensorParametersSpec"
)


@_attrs_define
class ColumnAccuracyTotalNotNullCountMatchPercentSensorParametersSpec:
    """
    Attributes:
        filter_ (Union[Unset, str]): SQL WHERE clause added to the sensor query. Both the table level filter and a
            sensor query filter are added, separated by an AND operator.
        referenced_table (Union[Unset, str]): This field can be used to define the name of the table to be compared to.
            In order to define the name of the table, user should write correct name as a String.
        referenced_column (Union[Unset, str]): This field can be used to define the name of the column to be compared
            to. In order to define the name of the column, user should write correct name as a String.
    """

    filter_: Union[Unset, str] = UNSET
    referenced_table: Union[Unset, str] = UNSET
    referenced_column: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        filter_ = self.filter_
        referenced_table = self.referenced_table
        referenced_column = self.referenced_column

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if filter_ is not UNSET:
            field_dict["filter"] = filter_
        if referenced_table is not UNSET:
            field_dict["referenced_table"] = referenced_table
        if referenced_column is not UNSET:
            field_dict["referenced_column"] = referenced_column

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        filter_ = d.pop("filter", UNSET)

        referenced_table = d.pop("referenced_table", UNSET)

        referenced_column = d.pop("referenced_column", UNSET)

        column_accuracy_total_not_null_count_match_percent_sensor_parameters_spec = cls(
            filter_=filter_,
            referenced_table=referenced_table,
            referenced_column=referenced_column,
        )

        column_accuracy_total_not_null_count_match_percent_sensor_parameters_spec.additional_properties = (
            d
        )
        return column_accuracy_total_not_null_count_match_percent_sensor_parameters_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.data_grouping_dimension_source import DataGroupingDimensionSource
from ..types import UNSET, Unset

T = TypeVar("T", bound="DataGroupingDimensionSpec")


@_attrs_define
class DataGroupingDimensionSpec:
    """
    Attributes:
        source (Union[Unset, DataGroupingDimensionSource]):
        tag (Union[Unset, str]): The value assigned to a data quality grouping dimension when the source is 'tag'.
            Assign a hardcoded (static) data grouping dimension value (tag) when there are multiple similar tables that
            store the same data for different areas (countries, etc.). This could be a country name if a table or partition
            stores information for that country.
        column (Union[Unset, str]): Column name that contains a dynamic data grouping dimension value (for dynamic data-
            driven data groupings). Sensor queries will be extended with a GROUP BY {data group level colum name}, sensors
            (and alerts) will be calculated for each unique value of the specified column. Also a separate time series will
            be tracked for each value.
        name (Union[Unset, str]): Data grouping dimension name.
    """

    source: Union[Unset, DataGroupingDimensionSource] = UNSET
    tag: Union[Unset, str] = UNSET
    column: Union[Unset, str] = UNSET
    name: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        source: Union[Unset, str] = UNSET
        if not isinstance(self.source, Unset):
            source = self.source.value

        tag = self.tag
        column = self.column
        name = self.name

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if source is not UNSET:
            field_dict["source"] = source
        if tag is not UNSET:
            field_dict["tag"] = tag
        if column is not UNSET:
            field_dict["column"] = column
        if name is not UNSET:
            field_dict["name"] = name

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _source = d.pop("source", UNSET)
        source: Union[Unset, DataGroupingDimensionSource]
        if isinstance(_source, Unset):
            source = UNSET
        else:
            source = DataGroupingDimensionSource(_source)

        tag = d.pop("tag", UNSET)

        column = d.pop("column", UNSET)

        name = d.pop("name", UNSET)

        data_grouping_dimension_spec = cls(
            source=source,
            tag=tag,
            column=column,
            name=name,
        )

        data_grouping_dimension_spec.additional_properties = d
        return data_grouping_dimension_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_text_length_above_max_length_check_spec import (
        ColumnTextLengthAboveMaxLengthCheckSpec,
    )
    from ..models.column_text_length_above_max_length_percent_check_spec import (
        ColumnTextLengthAboveMaxLengthPercentCheckSpec,
    )
    from ..models.column_text_length_below_min_length_check_spec import (
        ColumnTextLengthBelowMinLengthCheckSpec,
    )
    from ..models.column_text_length_below_min_length_percent_check_spec import (
        ColumnTextLengthBelowMinLengthPercentCheckSpec,
    )
    from ..models.column_text_length_in_range_percent_check_spec import (
        ColumnTextLengthInRangePercentCheckSpec,
    )
    from ..models.column_text_max_length_check_spec import ColumnTextMaxLengthCheckSpec
    from ..models.column_text_mean_length_check_spec import (
        ColumnTextMeanLengthCheckSpec,
    )
    from ..models.column_text_min_length_check_spec import ColumnTextMinLengthCheckSpec
    from ..models.column_text_monthly_partitioned_checks_spec_custom_checks import (
        ColumnTextMonthlyPartitionedChecksSpecCustomChecks,
    )
    from ..models.column_text_parsable_to_boolean_percent_check_spec import (
        ColumnTextParsableToBooleanPercentCheckSpec,
    )
    from ..models.column_text_parsable_to_date_percent_check_spec import (
        ColumnTextParsableToDatePercentCheckSpec,
    )
    from ..models.column_text_parsable_to_float_percent_check_spec import (
        ColumnTextParsableToFloatPercentCheckSpec,
    )
    from ..models.column_text_parsable_to_integer_percent_check_spec import (
        ColumnTextParsableToIntegerPercentCheckSpec,
    )
    from ..models.column_text_surrounded_by_whitespace_check_spec import (
        ColumnTextSurroundedByWhitespaceCheckSpec,
    )
    from ..models.column_text_surrounded_by_whitespace_percent_check_spec import (
        ColumnTextSurroundedByWhitespacePercentCheckSpec,
    )
    from ..models.column_text_valid_country_code_percent_check_spec import (
        ColumnTextValidCountryCodePercentCheckSpec,
    )
    from ..models.column_text_valid_currency_code_percent_check_spec import (
        ColumnTextValidCurrencyCodePercentCheckSpec,
    )


T = TypeVar("T", bound="ColumnTextMonthlyPartitionedChecksSpec")


@_attrs_define
class ColumnTextMonthlyPartitionedChecksSpec:
    """
    Attributes:
        custom_checks (Union[Unset, ColumnTextMonthlyPartitionedChecksSpecCustomChecks]): Dictionary of additional
            custom checks within this category. The keys are check names defined in the definition section. The sensor
            parameters and rules should match the type of the configured sensor and rule for the custom check.
        monthly_partition_text_max_length (Union[Unset, ColumnTextMaxLengthCheckSpec]):
        monthly_partition_text_min_length (Union[Unset, ColumnTextMinLengthCheckSpec]):
        monthly_partition_text_mean_length (Union[Unset, ColumnTextMeanLengthCheckSpec]):
        monthly_partition_text_length_below_min_length (Union[Unset, ColumnTextLengthBelowMinLengthCheckSpec]):
        monthly_partition_text_length_below_min_length_percent (Union[Unset,
            ColumnTextLengthBelowMinLengthPercentCheckSpec]):
        monthly_partition_text_length_above_max_length (Union[Unset, ColumnTextLengthAboveMaxLengthCheckSpec]):
        monthly_partition_text_length_above_max_length_percent (Union[Unset,
            ColumnTextLengthAboveMaxLengthPercentCheckSpec]):
        monthly_partition_text_length_in_range_percent (Union[Unset, ColumnTextLengthInRangePercentCheckSpec]):
        monthly_partition_text_parsable_to_boolean_percent (Union[Unset, ColumnTextParsableToBooleanPercentCheckSpec]):
        monthly_partition_text_parsable_to_integer_percent (Union[Unset, ColumnTextParsableToIntegerPercentCheckSpec]):
        monthly_partition_text_parsable_to_float_percent (Union[Unset, ColumnTextParsableToFloatPercentCheckSpec]):
        monthly_partition_text_parsable_to_date_percent (Union[Unset, ColumnTextParsableToDatePercentCheckSpec]):
        monthly_partition_text_surrounded_by_whitespace (Union[Unset, ColumnTextSurroundedByWhitespaceCheckSpec]):
        monthly_partition_text_surrounded_by_whitespace_percent (Union[Unset,
            ColumnTextSurroundedByWhitespacePercentCheckSpec]):
        monthly_partition_text_valid_country_code_percent (Union[Unset, ColumnTextValidCountryCodePercentCheckSpec]):
        monthly_partition_text_valid_currency_code_percent (Union[Unset, ColumnTextValidCurrencyCodePercentCheckSpec]):
    """

    custom_checks: Union[
        Unset, "ColumnTextMonthlyPartitionedChecksSpecCustomChecks"
    ] = UNSET
    monthly_partition_text_max_length: Union[
        Unset, "ColumnTextMaxLengthCheckSpec"
    ] = UNSET
    monthly_partition_text_min_length: Union[
        Unset, "ColumnTextMinLengthCheckSpec"
    ] = UNSET
    monthly_partition_text_mean_length: Union[
        Unset, "ColumnTextMeanLengthCheckSpec"
    ] = UNSET
    monthly_partition_text_length_below_min_length: Union[
        Unset, "ColumnTextLengthBelowMinLengthCheckSpec"
    ] = UNSET
    monthly_partition_text_length_below_min_length_percent: Union[
        Unset, "ColumnTextLengthBelowMinLengthPercentCheckSpec"
    ] = UNSET
    monthly_partition_text_length_above_max_length: Union[
        Unset, "ColumnTextLengthAboveMaxLengthCheckSpec"
    ] = UNSET
    monthly_partition_text_length_above_max_length_percent: Union[
        Unset, "ColumnTextLengthAboveMaxLengthPercentCheckSpec"
    ] = UNSET
    monthly_partition_text_length_in_range_percent: Union[
        Unset, "ColumnTextLengthInRangePercentCheckSpec"
    ] = UNSET
    monthly_partition_text_parsable_to_boolean_percent: Union[
        Unset, "ColumnTextParsableToBooleanPercentCheckSpec"
    ] = UNSET
    monthly_partition_text_parsable_to_integer_percent: Union[
        Unset, "ColumnTextParsableToIntegerPercentCheckSpec"
    ] = UNSET
    monthly_partition_text_parsable_to_float_percent: Union[
        Unset, "ColumnTextParsableToFloatPercentCheckSpec"
    ] = UNSET
    monthly_partition_text_parsable_to_date_percent: Union[
        Unset, "ColumnTextParsableToDatePercentCheckSpec"
    ] = UNSET
    monthly_partition_text_surrounded_by_whitespace: Union[
        Unset, "ColumnTextSurroundedByWhitespaceCheckSpec"
    ] = UNSET
    monthly_partition_text_surrounded_by_whitespace_percent: Union[
        Unset, "ColumnTextSurroundedByWhitespacePercentCheckSpec"
    ] = UNSET
    monthly_partition_text_valid_country_code_percent: Union[
        Unset, "ColumnTextValidCountryCodePercentCheckSpec"
    ] = UNSET
    monthly_partition_text_valid_currency_code_percent: Union[
        Unset, "ColumnTextValidCurrencyCodePercentCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        custom_checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom_checks, Unset):
            custom_checks = self.custom_checks.to_dict()

        monthly_partition_text_max_length: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_text_max_length, Unset):
            monthly_partition_text_max_length = (
                self.monthly_partition_text_max_length.to_dict()
            )

        monthly_partition_text_min_length: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_text_min_length, Unset):
            monthly_partition_text_min_length = (
                self.monthly_partition_text_min_length.to_dict()
            )

        monthly_partition_text_mean_length: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_text_mean_length, Unset):
            monthly_partition_text_mean_length = (
                self.monthly_partition_text_mean_length.to_dict()
            )

        monthly_partition_text_length_below_min_length: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.monthly_partition_text_length_below_min_length, Unset):
            monthly_partition_text_length_below_min_length = (
                self.monthly_partition_text_length_below_min_length.to_dict()
            )

        monthly_partition_text_length_below_min_length_percent: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(
            self.monthly_partition_text_length_below_min_length_percent, Unset
        ):
            monthly_partition_text_length_below_min_length_percent = (
                self.monthly_partition_text_length_below_min_length_percent.to_dict()
            )

        monthly_partition_text_length_above_max_length: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.monthly_partition_text_length_above_max_length, Unset):
            monthly_partition_text_length_above_max_length = (
                self.monthly_partition_text_length_above_max_length.to_dict()
            )

        monthly_partition_text_length_above_max_length_percent: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(
            self.monthly_partition_text_length_above_max_length_percent, Unset
        ):
            monthly_partition_text_length_above_max_length_percent = (
                self.monthly_partition_text_length_above_max_length_percent.to_dict()
            )

        monthly_partition_text_length_in_range_percent: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.monthly_partition_text_length_in_range_percent, Unset):
            monthly_partition_text_length_in_range_percent = (
                self.monthly_partition_text_length_in_range_percent.to_dict()
            )

        monthly_partition_text_parsable_to_boolean_percent: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(
            self.monthly_partition_text_parsable_to_boolean_percent, Unset
        ):
            monthly_partition_text_parsable_to_boolean_percent = (
                self.monthly_partition_text_parsable_to_boolean_percent.to_dict()
            )

        monthly_partition_text_parsable_to_integer_percent: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(
            self.monthly_partition_text_parsable_to_integer_percent, Unset
        ):
            monthly_partition_text_parsable_to_integer_percent = (
                self.monthly_partition_text_parsable_to_integer_percent.to_dict()
            )

        monthly_partition_text_parsable_to_float_percent: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.monthly_partition_text_parsable_to_float_percent, Unset):
            monthly_partition_text_parsable_to_float_percent = (
                self.monthly_partition_text_parsable_to_float_percent.to_dict()
            )

        monthly_partition_text_parsable_to_date_percent: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.monthly_partition_text_parsable_to_date_percent, Unset):
            monthly_partition_text_parsable_to_date_percent = (
                self.monthly_partition_text_parsable_to_date_percent.to_dict()
            )

        monthly_partition_text_surrounded_by_whitespace: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.monthly_partition_text_surrounded_by_whitespace, Unset):
            monthly_partition_text_surrounded_by_whitespace = (
                self.monthly_partition_text_surrounded_by_whitespace.to_dict()
            )

        monthly_partition_text_surrounded_by_whitespace_percent: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(
            self.monthly_partition_text_surrounded_by_whitespace_percent, Unset
        ):
            monthly_partition_text_surrounded_by_whitespace_percent = (
                self.monthly_partition_text_surrounded_by_whitespace_percent.to_dict()
            )

        monthly_partition_text_valid_country_code_percent: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(
            self.monthly_partition_text_valid_country_code_percent, Unset
        ):
            monthly_partition_text_valid_country_code_percent = (
                self.monthly_partition_text_valid_country_code_percent.to_dict()
            )

        monthly_partition_text_valid_currency_code_percent: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(
            self.monthly_partition_text_valid_currency_code_percent, Unset
        ):
            monthly_partition_text_valid_currency_code_percent = (
                self.monthly_partition_text_valid_currency_code_percent.to_dict()
            )

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if custom_checks is not UNSET:
            field_dict["custom_checks"] = custom_checks
        if monthly_partition_text_max_length is not UNSET:
            field_dict[
                "monthly_partition_text_max_length"
            ] = monthly_partition_text_max_length
        if monthly_partition_text_min_length is not UNSET:
            field_dict[
                "monthly_partition_text_min_length"
            ] = monthly_partition_text_min_length
        if monthly_partition_text_mean_length is not UNSET:
            field_dict[
                "monthly_partition_text_mean_length"
            ] = monthly_partition_text_mean_length
        if monthly_partition_text_length_below_min_length is not UNSET:
            field_dict[
                "monthly_partition_text_length_below_min_length"
            ] = monthly_partition_text_length_below_min_length
        if monthly_partition_text_length_below_min_length_percent is not UNSET:
            field_dict[
                "monthly_partition_text_length_below_min_length_percent"
            ] = monthly_partition_text_length_below_min_length_percent
        if monthly_partition_text_length_above_max_length is not UNSET:
            field_dict[
                "monthly_partition_text_length_above_max_length"
            ] = monthly_partition_text_length_above_max_length
        if monthly_partition_text_length_above_max_length_percent is not UNSET:
            field_dict[
                "monthly_partition_text_length_above_max_length_percent"
            ] = monthly_partition_text_length_above_max_length_percent
        if monthly_partition_text_length_in_range_percent is not UNSET:
            field_dict[
                "monthly_partition_text_length_in_range_percent"
            ] = monthly_partition_text_length_in_range_percent
        if monthly_partition_text_parsable_to_boolean_percent is not UNSET:
            field_dict[
                "monthly_partition_text_parsable_to_boolean_percent"
            ] = monthly_partition_text_parsable_to_boolean_percent
        if monthly_partition_text_parsable_to_integer_percent is not UNSET:
            field_dict[
                "monthly_partition_text_parsable_to_integer_percent"
            ] = monthly_partition_text_parsable_to_integer_percent
        if monthly_partition_text_parsable_to_float_percent is not UNSET:
            field_dict[
                "monthly_partition_text_parsable_to_float_percent"
            ] = monthly_partition_text_parsable_to_float_percent
        if monthly_partition_text_parsable_to_date_percent is not UNSET:
            field_dict[
                "monthly_partition_text_parsable_to_date_percent"
            ] = monthly_partition_text_parsable_to_date_percent
        if monthly_partition_text_surrounded_by_whitespace is not UNSET:
            field_dict[
                "monthly_partition_text_surrounded_by_whitespace"
            ] = monthly_partition_text_surrounded_by_whitespace
        if monthly_partition_text_surrounded_by_whitespace_percent is not UNSET:
            field_dict[
                "monthly_partition_text_surrounded_by_whitespace_percent"
            ] = monthly_partition_text_surrounded_by_whitespace_percent
        if monthly_partition_text_valid_country_code_percent is not UNSET:
            field_dict[
                "monthly_partition_text_valid_country_code_percent"
            ] = monthly_partition_text_valid_country_code_percent
        if monthly_partition_text_valid_currency_code_percent is not UNSET:
            field_dict[
                "monthly_partition_text_valid_currency_code_percent"
            ] = monthly_partition_text_valid_currency_code_percent

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_text_length_above_max_length_check_spec import (
            ColumnTextLengthAboveMaxLengthCheckSpec,
        )
        from ..models.column_text_length_above_max_length_percent_check_spec import (
            ColumnTextLengthAboveMaxLengthPercentCheckSpec,
        )
        from ..models.column_text_length_below_min_length_check_spec import (
            ColumnTextLengthBelowMinLengthCheckSpec,
        )
        from ..models.column_text_length_below_min_length_percent_check_spec import (
            ColumnTextLengthBelowMinLengthPercentCheckSpec,
        )
        from ..models.column_text_length_in_range_percent_check_spec import (
            ColumnTextLengthInRangePercentCheckSpec,
        )
        from ..models.column_text_max_length_check_spec import (
            ColumnTextMaxLengthCheckSpec,
        )
        from ..models.column_text_mean_length_check_spec import (
            ColumnTextMeanLengthCheckSpec,
        )
        from ..models.column_text_min_length_check_spec import (
            ColumnTextMinLengthCheckSpec,
        )
        from ..models.column_text_monthly_partitioned_checks_spec_custom_checks import (
            ColumnTextMonthlyPartitionedChecksSpecCustomChecks,
        )
        from ..models.column_text_parsable_to_boolean_percent_check_spec import (
            ColumnTextParsableToBooleanPercentCheckSpec,
        )
        from ..models.column_text_parsable_to_date_percent_check_spec import (
            ColumnTextParsableToDatePercentCheckSpec,
        )
        from ..models.column_text_parsable_to_float_percent_check_spec import (
            ColumnTextParsableToFloatPercentCheckSpec,
        )
        from ..models.column_text_parsable_to_integer_percent_check_spec import (
            ColumnTextParsableToIntegerPercentCheckSpec,
        )
        from ..models.column_text_surrounded_by_whitespace_check_spec import (
            ColumnTextSurroundedByWhitespaceCheckSpec,
        )
        from ..models.column_text_surrounded_by_whitespace_percent_check_spec import (
            ColumnTextSurroundedByWhitespacePercentCheckSpec,
        )
        from ..models.column_text_valid_country_code_percent_check_spec import (
            ColumnTextValidCountryCodePercentCheckSpec,
        )
        from ..models.column_text_valid_currency_code_percent_check_spec import (
            ColumnTextValidCurrencyCodePercentCheckSpec,
        )

        d = src_dict.copy()
        _custom_checks = d.pop("custom_checks", UNSET)
        custom_checks: Union[Unset, ColumnTextMonthlyPartitionedChecksSpecCustomChecks]
        if isinstance(_custom_checks, Unset):
            custom_checks = UNSET
        else:
            custom_checks = (
                ColumnTextMonthlyPartitionedChecksSpecCustomChecks.from_dict(
                    _custom_checks
                )
            )

        _monthly_partition_text_max_length = d.pop(
            "monthly_partition_text_max_length", UNSET
        )
        monthly_partition_text_max_length: Union[Unset, ColumnTextMaxLengthCheckSpec]
        if isinstance(_monthly_partition_text_max_length, Unset):
            monthly_partition_text_max_length = UNSET
        else:
            monthly_partition_text_max_length = ColumnTextMaxLengthCheckSpec.from_dict(
                _monthly_partition_text_max_length
            )

        _monthly_partition_text_min_length = d.pop(
            "monthly_partition_text_min_length", UNSET
        )
        monthly_partition_text_min_length: Union[Unset, ColumnTextMinLengthCheckSpec]
        if isinstance(_monthly_partition_text_min_length, Unset):
            monthly_partition_text_min_length = UNSET
        else:
            monthly_partition_text_min_length = ColumnTextMinLengthCheckSpec.from_dict(
                _monthly_partition_text_min_length
            )

        _monthly_partition_text_mean_length = d.pop(
            "monthly_partition_text_mean_length", UNSET
        )
        monthly_partition_text_mean_length: Union[Unset, ColumnTextMeanLengthCheckSpec]
        if isinstance(_monthly_partition_text_mean_length, Unset):
            monthly_partition_text_mean_length = UNSET
        else:
            monthly_partition_text_mean_length = (
                ColumnTextMeanLengthCheckSpec.from_dict(
                    _monthly_partition_text_mean_length
                )
            )

        _monthly_partition_text_length_below_min_length = d.pop(
            "monthly_partition_text_length_below_min_length", UNSET
        )
        monthly_partition_text_length_below_min_length: Union[
            Unset, ColumnTextLengthBelowMinLengthCheckSpec
        ]
        if isinstance(_monthly_partition_text_length_below_min_length, Unset):
            monthly_partition_text_length_below_min_length = UNSET
        else:
            monthly_partition_text_length_below_min_length = (
                ColumnTextLengthBelowMinLengthCheckSpec.from_dict(
                    _monthly_partition_text_length_below_min_length
                )
            )

        _monthly_partition_text_length_below_min_length_percent = d.pop(
            "monthly_partition_text_length_below_min_length_percent", UNSET
        )
        monthly_partition_text_length_below_min_length_percent: Union[
            Unset, ColumnTextLengthBelowMinLengthPercentCheckSpec
        ]
        if isinstance(_monthly_partition_text_length_below_min_length_percent, Unset):
            monthly_partition_text_length_below_min_length_percent = UNSET
        else:
            monthly_partition_text_length_below_min_length_percent = (
                ColumnTextLengthBelowMinLengthPercentCheckSpec.from_dict(
                    _monthly_partition_text_length_below_min_length_percent
                )
            )

        _monthly_partition_text_length_above_max_length = d.pop(
            "monthly_partition_text_length_above_max_length", UNSET
        )
        monthly_partition_text_length_above_max_length: Union[
            Unset, ColumnTextLengthAboveMaxLengthCheckSpec
        ]
        if isinstance(_monthly_partition_text_length_above_max_length, Unset):
            monthly_partition_text_length_above_max_length = UNSET
        else:
            monthly_partition_text_length_above_max_length = (
                ColumnTextLengthAboveMaxLengthCheckSpec.from_dict(
                    _monthly_partition_text_length_above_max_length
                )
            )

        _monthly_partition_text_length_above_max_length_percent = d.pop(
            "monthly_partition_text_length_above_max_length_percent", UNSET
        )
        monthly_partition_text_length_above_max_length_percent: Union[
            Unset, ColumnTextLengthAboveMaxLengthPercentCheckSpec
        ]
        if isinstance(_monthly_partition_text_length_above_max_length_percent, Unset):
            monthly_partition_text_length_above_max_length_percent = UNSET
        else:
            monthly_partition_text_length_above_max_length_percent = (
                ColumnTextLengthAboveMaxLengthPercentCheckSpec.from_dict(
                    _monthly_partition_text_length_above_max_length_percent
                )
            )

        _monthly_partition_text_length_in_range_percent = d.pop(
            "monthly_partition_text_length_in_range_percent", UNSET
        )
        monthly_partition_text_length_in_range_percent: Union[
            Unset, ColumnTextLengthInRangePercentCheckSpec
        ]
        if isinstance(_monthly_partition_text_length_in_range_percent, Unset):
            monthly_partition_text_length_in_range_percent = UNSET
        else:
            monthly_partition_text_length_in_range_percent = (
                ColumnTextLengthInRangePercentCheckSpec.from_dict(
                    _monthly_partition_text_length_in_range_percent
                )
            )

        _monthly_partition_text_parsable_to_boolean_percent = d.pop(
            "monthly_partition_text_parsable_to_boolean_percent", UNSET
        )
        monthly_partition_text_parsable_to_boolean_percent: Union[
            Unset, ColumnTextParsableToBooleanPercentCheckSpec
        ]
        if isinstance(_monthly_partition_text_parsable_to_boolean_percent, Unset):
            monthly_partition_text_parsable_to_boolean_percent = UNSET
        else:
            monthly_partition_text_parsable_to_boolean_percent = (
                ColumnTextParsableToBooleanPercentCheckSpec.from_dict(
                    _monthly_partition_text_parsable_to_boolean_percent
                )
            )

        _monthly_partition_text_parsable_to_integer_percent = d.pop(
            "monthly_partition_text_parsable_to_integer_percent", UNSET
        )
        monthly_partition_text_parsable_to_integer_percent: Union[
            Unset, ColumnTextParsableToIntegerPercentCheckSpec
        ]
        if isinstance(_monthly_partition_text_parsable_to_integer_percent, Unset):
            monthly_partition_text_parsable_to_integer_percent = UNSET
        else:
            monthly_partition_text_parsable_to_integer_percent = (
                ColumnTextParsableToIntegerPercentCheckSpec.from_dict(
                    _monthly_partition_text_parsable_to_integer_percent
                )
            )

        _monthly_partition_text_parsable_to_float_percent = d.pop(
            "monthly_partition_text_parsable_to_float_percent", UNSET
        )
        monthly_partition_text_parsable_to_float_percent: Union[
            Unset, ColumnTextParsableToFloatPercentCheckSpec
        ]
        if isinstance(_monthly_partition_text_parsable_to_float_percent, Unset):
            monthly_partition_text_parsable_to_float_percent = UNSET
        else:
            monthly_partition_text_parsable_to_float_percent = (
                ColumnTextParsableToFloatPercentCheckSpec.from_dict(
                    _monthly_partition_text_parsable_to_float_percent
                )
            )

        _monthly_partition_text_parsable_to_date_percent = d.pop(
            "monthly_partition_text_parsable_to_date_percent", UNSET
        )
        monthly_partition_text_parsable_to_date_percent: Union[
            Unset, ColumnTextParsableToDatePercentCheckSpec
        ]
        if isinstance(_monthly_partition_text_parsable_to_date_percent, Unset):
            monthly_partition_text_parsable_to_date_percent = UNSET
        else:
            monthly_partition_text_parsable_to_date_percent = (
                ColumnTextParsableToDatePercentCheckSpec.from_dict(
                    _monthly_partition_text_parsable_to_date_percent
                )
            )

        _monthly_partition_text_surrounded_by_whitespace = d.pop(
            "monthly_partition_text_surrounded_by_whitespace", UNSET
        )
        monthly_partition_text_surrounded_by_whitespace: Union[
            Unset, ColumnTextSurroundedByWhitespaceCheckSpec
        ]
        if isinstance(_monthly_partition_text_surrounded_by_whitespace, Unset):
            monthly_partition_text_surrounded_by_whitespace = UNSET
        else:
            monthly_partition_text_surrounded_by_whitespace = (
                ColumnTextSurroundedByWhitespaceCheckSpec.from_dict(
                    _monthly_partition_text_surrounded_by_whitespace
                )
            )

        _monthly_partition_text_surrounded_by_whitespace_percent = d.pop(
            "monthly_partition_text_surrounded_by_whitespace_percent", UNSET
        )
        monthly_partition_text_surrounded_by_whitespace_percent: Union[
            Unset, ColumnTextSurroundedByWhitespacePercentCheckSpec
        ]
        if isinstance(_monthly_partition_text_surrounded_by_whitespace_percent, Unset):
            monthly_partition_text_surrounded_by_whitespace_percent = UNSET
        else:
            monthly_partition_text_surrounded_by_whitespace_percent = (
                ColumnTextSurroundedByWhitespacePercentCheckSpec.from_dict(
                    _monthly_partition_text_surrounded_by_whitespace_percent
                )
            )

        _monthly_partition_text_valid_country_code_percent = d.pop(
            "monthly_partition_text_valid_country_code_percent", UNSET
        )
        monthly_partition_text_valid_country_code_percent: Union[
            Unset, ColumnTextValidCountryCodePercentCheckSpec
        ]
        if isinstance(_monthly_partition_text_valid_country_code_percent, Unset):
            monthly_partition_text_valid_country_code_percent = UNSET
        else:
            monthly_partition_text_valid_country_code_percent = (
                ColumnTextValidCountryCodePercentCheckSpec.from_dict(
                    _monthly_partition_text_valid_country_code_percent
                )
            )

        _monthly_partition_text_valid_currency_code_percent = d.pop(
            "monthly_partition_text_valid_currency_code_percent", UNSET
        )
        monthly_partition_text_valid_currency_code_percent: Union[
            Unset, ColumnTextValidCurrencyCodePercentCheckSpec
        ]
        if isinstance(_monthly_partition_text_valid_currency_code_percent, Unset):
            monthly_partition_text_valid_currency_code_percent = UNSET
        else:
            monthly_partition_text_valid_currency_code_percent = (
                ColumnTextValidCurrencyCodePercentCheckSpec.from_dict(
                    _monthly_partition_text_valid_currency_code_percent
                )
            )

        column_text_monthly_partitioned_checks_spec = cls(
            custom_checks=custom_checks,
            monthly_partition_text_max_length=monthly_partition_text_max_length,
            monthly_partition_text_min_length=monthly_partition_text_min_length,
            monthly_partition_text_mean_length=monthly_partition_text_mean_length,
            monthly_partition_text_length_below_min_length=monthly_partition_text_length_below_min_length,
            monthly_partition_text_length_below_min_length_percent=monthly_partition_text_length_below_min_length_percent,
            monthly_partition_text_length_above_max_length=monthly_partition_text_length_above_max_length,
            monthly_partition_text_length_above_max_length_percent=monthly_partition_text_length_above_max_length_percent,
            monthly_partition_text_length_in_range_percent=monthly_partition_text_length_in_range_percent,
            monthly_partition_text_parsable_to_boolean_percent=monthly_partition_text_parsable_to_boolean_percent,
            monthly_partition_text_parsable_to_integer_percent=monthly_partition_text_parsable_to_integer_percent,
            monthly_partition_text_parsable_to_float_percent=monthly_partition_text_parsable_to_float_percent,
            monthly_partition_text_parsable_to_date_percent=monthly_partition_text_parsable_to_date_percent,
            monthly_partition_text_surrounded_by_whitespace=monthly_partition_text_surrounded_by_whitespace,
            monthly_partition_text_surrounded_by_whitespace_percent=monthly_partition_text_surrounded_by_whitespace_percent,
            monthly_partition_text_valid_country_code_percent=monthly_partition_text_valid_country_code_percent,
            monthly_partition_text_valid_currency_code_percent=monthly_partition_text_valid_currency_code_percent,
        )

        column_text_monthly_partitioned_checks_spec.additional_properties = d
        return column_text_monthly_partitioned_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Dict, List, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.check_configuration_model import CheckConfigurationModel
from ...models.check_target import CheckTarget
from ...models.check_time_scale import CheckTimeScale
from ...types import UNSET, Response, Unset


def _get_kwargs(
    connection_name: str,
    schema_name: str,
    time_scale: CheckTimeScale,
    *,
    table_name_pattern: Union[Unset, None, str] = UNSET,
    column_name_pattern: Union[Unset, None, str] = UNSET,
    column_data_type: Union[Unset, None, str] = UNSET,
    check_target: Union[Unset, None, CheckTarget] = UNSET,
    check_category: Union[Unset, None, str] = UNSET,
    check_name: Union[Unset, None, str] = UNSET,
    check_enabled: Union[Unset, None, bool] = UNSET,
    check_configured: Union[Unset, None, bool] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
) -> Dict[str, Any]:
    pass

    params: Dict[str, Any] = {}
    params["tableNamePattern"] = table_name_pattern

    params["columnNamePattern"] = column_name_pattern

    params["columnDataType"] = column_data_type

    json_check_target: Union[Unset, None, str] = UNSET
    if not isinstance(check_target, Unset):
        json_check_target = check_target.value if check_target else None

    params["checkTarget"] = json_check_target

    params["checkCategory"] = check_category

    params["checkName"] = check_name

    params["checkEnabled"] = check_enabled

    params["checkConfigured"] = check_configured

    params["limit"] = limit

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": "api/connections/{connectionName}/schemas/{schemaName}/partitioned/{timeScale}/model".format(
            connectionName=connection_name,
            schemaName=schema_name,
            timeScale=time_scale,
        ),
        "params": params,
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[List["CheckConfigurationModel"]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in _response_200:
            response_200_item = CheckConfigurationModel.from_dict(
                response_200_item_data
            )

            response_200.append(response_200_item)

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[List["CheckConfigurationModel"]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    connection_name: str,
    schema_name: str,
    time_scale: CheckTimeScale,
    *,
    client: AuthenticatedClient,
    table_name_pattern: Union[Unset, None, str] = UNSET,
    column_name_pattern: Union[Unset, None, str] = UNSET,
    column_data_type: Union[Unset, None, str] = UNSET,
    check_target: Union[Unset, None, CheckTarget] = UNSET,
    check_category: Union[Unset, None, str] = UNSET,
    check_name: Union[Unset, None, str] = UNSET,
    check_enabled: Union[Unset, None, bool] = UNSET,
    check_configured: Union[Unset, None, bool] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
) -> Response[List["CheckConfigurationModel"]]:
    """getSchemaPartitionedChecksModel

     Return a UI friendly model of configurations for data quality partitioned checks on a schema

    Args:
        connection_name (str):
        schema_name (str):
        time_scale (CheckTimeScale):
        table_name_pattern (Union[Unset, None, str]):
        column_name_pattern (Union[Unset, None, str]):
        column_data_type (Union[Unset, None, str]):
        check_target (Union[Unset, None, CheckTarget]):
        check_category (Union[Unset, None, str]):
        check_name (Union[Unset, None, str]):
        check_enabled (Union[Unset, None, bool]):
        check_configured (Union[Unset, None, bool]):
        limit (Union[Unset, None, int]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[List['CheckConfigurationModel']]
    """

    kwargs = _get_kwargs(
        connection_name=connection_name,
        schema_name=schema_name,
        time_scale=time_scale,
        table_name_pattern=table_name_pattern,
        column_name_pattern=column_name_pattern,
        column_data_type=column_data_type,
        check_target=check_target,
        check_category=check_category,
        check_name=check_name,
        check_enabled=check_enabled,
        check_configured=check_configured,
        limit=limit,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    connection_name: str,
    schema_name: str,
    time_scale: CheckTimeScale,
    *,
    client: AuthenticatedClient,
    table_name_pattern: Union[Unset, None, str] = UNSET,
    column_name_pattern: Union[Unset, None, str] = UNSET,
    column_data_type: Union[Unset, None, str] = UNSET,
    check_target: Union[Unset, None, CheckTarget] = UNSET,
    check_category: Union[Unset, None, str] = UNSET,
    check_name: Union[Unset, None, str] = UNSET,
    check_enabled: Union[Unset, None, bool] = UNSET,
    check_configured: Union[Unset, None, bool] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
) -> Optional[List["CheckConfigurationModel"]]:
    """getSchemaPartitionedChecksModel

     Return a UI friendly model of configurations for data quality partitioned checks on a schema

    Args:
        connection_name (str):
        schema_name (str):
        time_scale (CheckTimeScale):
        table_name_pattern (Union[Unset, None, str]):
        column_name_pattern (Union[Unset, None, str]):
        column_data_type (Union[Unset, None, str]):
        check_target (Union[Unset, None, CheckTarget]):
        check_category (Union[Unset, None, str]):
        check_name (Union[Unset, None, str]):
        check_enabled (Union[Unset, None, bool]):
        check_configured (Union[Unset, None, bool]):
        limit (Union[Unset, None, int]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        List['CheckConfigurationModel']
    """

    return sync_detailed(
        connection_name=connection_name,
        schema_name=schema_name,
        time_scale=time_scale,
        client=client,
        table_name_pattern=table_name_pattern,
        column_name_pattern=column_name_pattern,
        column_data_type=column_data_type,
        check_target=check_target,
        check_category=check_category,
        check_name=check_name,
        check_enabled=check_enabled,
        check_configured=check_configured,
        limit=limit,
    ).parsed


async def asyncio_detailed(
    connection_name: str,
    schema_name: str,
    time_scale: CheckTimeScale,
    *,
    client: AuthenticatedClient,
    table_name_pattern: Union[Unset, None, str] = UNSET,
    column_name_pattern: Union[Unset, None, str] = UNSET,
    column_data_type: Union[Unset, None, str] = UNSET,
    check_target: Union[Unset, None, CheckTarget] = UNSET,
    check_category: Union[Unset, None, str] = UNSET,
    check_name: Union[Unset, None, str] = UNSET,
    check_enabled: Union[Unset, None, bool] = UNSET,
    check_configured: Union[Unset, None, bool] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
) -> Response[List["CheckConfigurationModel"]]:
    """getSchemaPartitionedChecksModel

     Return a UI friendly model of configurations for data quality partitioned checks on a schema

    Args:
        connection_name (str):
        schema_name (str):
        time_scale (CheckTimeScale):
        table_name_pattern (Union[Unset, None, str]):
        column_name_pattern (Union[Unset, None, str]):
        column_data_type (Union[Unset, None, str]):
        check_target (Union[Unset, None, CheckTarget]):
        check_category (Union[Unset, None, str]):
        check_name (Union[Unset, None, str]):
        check_enabled (Union[Unset, None, bool]):
        check_configured (Union[Unset, None, bool]):
        limit (Union[Unset, None, int]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[List['CheckConfigurationModel']]
    """

    kwargs = _get_kwargs(
        connection_name=connection_name,
        schema_name=schema_name,
        time_scale=time_scale,
        table_name_pattern=table_name_pattern,
        column_name_pattern=column_name_pattern,
        column_data_type=column_data_type,
        check_target=check_target,
        check_category=check_category,
        check_name=check_name,
        check_enabled=check_enabled,
        check_configured=check_configured,
        limit=limit,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    connection_name: str,
    schema_name: str,
    time_scale: CheckTimeScale,
    *,
    client: AuthenticatedClient,
    table_name_pattern: Union[Unset, None, str] = UNSET,
    column_name_pattern: Union[Unset, None, str] = UNSET,
    column_data_type: Union[Unset, None, str] = UNSET,
    check_target: Union[Unset, None, CheckTarget] = UNSET,
    check_category: Union[Unset, None, str] = UNSET,
    check_name: Union[Unset, None, str] = UNSET,
    check_enabled: Union[Unset, None, bool] = UNSET,
    check_configured: Union[Unset, None, bool] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
) -> Optional[List["CheckConfigurationModel"]]:
    """getSchemaPartitionedChecksModel

     Return a UI friendly model of configurations for data quality partitioned checks on a schema

    Args:
        connection_name (str):
        schema_name (str):
        time_scale (CheckTimeScale):
        table_name_pattern (Union[Unset, None, str]):
        column_name_pattern (Union[Unset, None, str]):
        column_data_type (Union[Unset, None, str]):
        check_target (Union[Unset, None, CheckTarget]):
        check_category (Union[Unset, None, str]):
        check_name (Union[Unset, None, str]):
        check_enabled (Union[Unset, None, bool]):
        check_configured (Union[Unset, None, bool]):
        limit (Union[Unset, None, int]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        List['CheckConfigurationModel']
    """

    return (
        await asyncio_detailed(
            connection_name=connection_name,
            schema_name=schema_name,
            time_scale=time_scale,
            client=client,
            table_name_pattern=table_name_pattern,
            column_name_pattern=column_name_pattern,
            column_data_type=column_data_type,
            check_target=check_target,
            check_category=check_category,
            check_name=check_name,
            check_enabled=check_enabled,
            check_configured=check_configured,
            limit=limit,
        )
    ).parsed



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_blanks_empty_text_found_check_spec import (
        ColumnBlanksEmptyTextFoundCheckSpec,
    )
    from ..models.column_blanks_empty_text_percent_check_spec import (
        ColumnBlanksEmptyTextPercentCheckSpec,
    )
    from ..models.column_blanks_monthly_monitoring_checks_spec_custom_checks import (
        ColumnBlanksMonthlyMonitoringChecksSpecCustomChecks,
    )
    from ..models.column_blanks_null_placeholder_text_found_check_spec import (
        ColumnBlanksNullPlaceholderTextFoundCheckSpec,
    )
    from ..models.column_blanks_null_placeholder_text_percent_check_spec import (
        ColumnBlanksNullPlaceholderTextPercentCheckSpec,
    )
    from ..models.column_blanks_whitespace_text_found_check_spec import (
        ColumnBlanksWhitespaceTextFoundCheckSpec,
    )
    from ..models.column_blanks_whitespace_text_percent_check_spec import (
        ColumnBlanksWhitespaceTextPercentCheckSpec,
    )


T = TypeVar("T", bound="ColumnBlanksMonthlyMonitoringChecksSpec")


@_attrs_define
class ColumnBlanksMonthlyMonitoringChecksSpec:
    """
    Attributes:
        custom_checks (Union[Unset, ColumnBlanksMonthlyMonitoringChecksSpecCustomChecks]): Dictionary of additional
            custom checks within this category. The keys are check names defined in the definition section. The sensor
            parameters and rules should match the type of the configured sensor and rule for the custom check.
        monthly_empty_text_found (Union[Unset, ColumnBlanksEmptyTextFoundCheckSpec]):
        monthly_whitespace_text_found (Union[Unset, ColumnBlanksWhitespaceTextFoundCheckSpec]):
        monthly_null_placeholder_text_found (Union[Unset, ColumnBlanksNullPlaceholderTextFoundCheckSpec]):
        monthly_empty_text_percent (Union[Unset, ColumnBlanksEmptyTextPercentCheckSpec]):
        monthly_whitespace_text_percent (Union[Unset, ColumnBlanksWhitespaceTextPercentCheckSpec]):
        monthly_null_placeholder_text_percent (Union[Unset, ColumnBlanksNullPlaceholderTextPercentCheckSpec]):
    """

    custom_checks: Union[
        Unset, "ColumnBlanksMonthlyMonitoringChecksSpecCustomChecks"
    ] = UNSET
    monthly_empty_text_found: Union[
        Unset, "ColumnBlanksEmptyTextFoundCheckSpec"
    ] = UNSET
    monthly_whitespace_text_found: Union[
        Unset, "ColumnBlanksWhitespaceTextFoundCheckSpec"
    ] = UNSET
    monthly_null_placeholder_text_found: Union[
        Unset, "ColumnBlanksNullPlaceholderTextFoundCheckSpec"
    ] = UNSET
    monthly_empty_text_percent: Union[
        Unset, "ColumnBlanksEmptyTextPercentCheckSpec"
    ] = UNSET
    monthly_whitespace_text_percent: Union[
        Unset, "ColumnBlanksWhitespaceTextPercentCheckSpec"
    ] = UNSET
    monthly_null_placeholder_text_percent: Union[
        Unset, "ColumnBlanksNullPlaceholderTextPercentCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        custom_checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom_checks, Unset):
            custom_checks = self.custom_checks.to_dict()

        monthly_empty_text_found: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_empty_text_found, Unset):
            monthly_empty_text_found = self.monthly_empty_text_found.to_dict()

        monthly_whitespace_text_found: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_whitespace_text_found, Unset):
            monthly_whitespace_text_found = self.monthly_whitespace_text_found.to_dict()

        monthly_null_placeholder_text_found: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_null_placeholder_text_found, Unset):
            monthly_null_placeholder_text_found = (
                self.monthly_null_placeholder_text_found.to_dict()
            )

        monthly_empty_text_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_empty_text_percent, Unset):
            monthly_empty_text_percent = self.monthly_empty_text_percent.to_dict()

        monthly_whitespace_text_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_whitespace_text_percent, Unset):
            monthly_whitespace_text_percent = (
                self.monthly_whitespace_text_percent.to_dict()
            )

        monthly_null_placeholder_text_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_null_placeholder_text_percent, Unset):
            monthly_null_placeholder_text_percent = (
                self.monthly_null_placeholder_text_percent.to_dict()
            )

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if custom_checks is not UNSET:
            field_dict["custom_checks"] = custom_checks
        if monthly_empty_text_found is not UNSET:
            field_dict["monthly_empty_text_found"] = monthly_empty_text_found
        if monthly_whitespace_text_found is not UNSET:
            field_dict["monthly_whitespace_text_found"] = monthly_whitespace_text_found
        if monthly_null_placeholder_text_found is not UNSET:
            field_dict[
                "monthly_null_placeholder_text_found"
            ] = monthly_null_placeholder_text_found
        if monthly_empty_text_percent is not UNSET:
            field_dict["monthly_empty_text_percent"] = monthly_empty_text_percent
        if monthly_whitespace_text_percent is not UNSET:
            field_dict[
                "monthly_whitespace_text_percent"
            ] = monthly_whitespace_text_percent
        if monthly_null_placeholder_text_percent is not UNSET:
            field_dict[
                "monthly_null_placeholder_text_percent"
            ] = monthly_null_placeholder_text_percent

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_blanks_empty_text_found_check_spec import (
            ColumnBlanksEmptyTextFoundCheckSpec,
        )
        from ..models.column_blanks_empty_text_percent_check_spec import (
            ColumnBlanksEmptyTextPercentCheckSpec,
        )
        from ..models.column_blanks_monthly_monitoring_checks_spec_custom_checks import (
            ColumnBlanksMonthlyMonitoringChecksSpecCustomChecks,
        )
        from ..models.column_blanks_null_placeholder_text_found_check_spec import (
            ColumnBlanksNullPlaceholderTextFoundCheckSpec,
        )
        from ..models.column_blanks_null_placeholder_text_percent_check_spec import (
            ColumnBlanksNullPlaceholderTextPercentCheckSpec,
        )
        from ..models.column_blanks_whitespace_text_found_check_spec import (
            ColumnBlanksWhitespaceTextFoundCheckSpec,
        )
        from ..models.column_blanks_whitespace_text_percent_check_spec import (
            ColumnBlanksWhitespaceTextPercentCheckSpec,
        )

        d = src_dict.copy()
        _custom_checks = d.pop("custom_checks", UNSET)
        custom_checks: Union[Unset, ColumnBlanksMonthlyMonitoringChecksSpecCustomChecks]
        if isinstance(_custom_checks, Unset):
            custom_checks = UNSET
        else:
            custom_checks = (
                ColumnBlanksMonthlyMonitoringChecksSpecCustomChecks.from_dict(
                    _custom_checks
                )
            )

        _monthly_empty_text_found = d.pop("monthly_empty_text_found", UNSET)
        monthly_empty_text_found: Union[Unset, ColumnBlanksEmptyTextFoundCheckSpec]
        if isinstance(_monthly_empty_text_found, Unset):
            monthly_empty_text_found = UNSET
        else:
            monthly_empty_text_found = ColumnBlanksEmptyTextFoundCheckSpec.from_dict(
                _monthly_empty_text_found
            )

        _monthly_whitespace_text_found = d.pop("monthly_whitespace_text_found", UNSET)
        monthly_whitespace_text_found: Union[
            Unset, ColumnBlanksWhitespaceTextFoundCheckSpec
        ]
        if isinstance(_monthly_whitespace_text_found, Unset):
            monthly_whitespace_text_found = UNSET
        else:
            monthly_whitespace_text_found = (
                ColumnBlanksWhitespaceTextFoundCheckSpec.from_dict(
                    _monthly_whitespace_text_found
                )
            )

        _monthly_null_placeholder_text_found = d.pop(
            "monthly_null_placeholder_text_found", UNSET
        )
        monthly_null_placeholder_text_found: Union[
            Unset, ColumnBlanksNullPlaceholderTextFoundCheckSpec
        ]
        if isinstance(_monthly_null_placeholder_text_found, Unset):
            monthly_null_placeholder_text_found = UNSET
        else:
            monthly_null_placeholder_text_found = (
                ColumnBlanksNullPlaceholderTextFoundCheckSpec.from_dict(
                    _monthly_null_placeholder_text_found
                )
            )

        _monthly_empty_text_percent = d.pop("monthly_empty_text_percent", UNSET)
        monthly_empty_text_percent: Union[Unset, ColumnBlanksEmptyTextPercentCheckSpec]
        if isinstance(_monthly_empty_text_percent, Unset):
            monthly_empty_text_percent = UNSET
        else:
            monthly_empty_text_percent = (
                ColumnBlanksEmptyTextPercentCheckSpec.from_dict(
                    _monthly_empty_text_percent
                )
            )

        _monthly_whitespace_text_percent = d.pop(
            "monthly_whitespace_text_percent", UNSET
        )
        monthly_whitespace_text_percent: Union[
            Unset, ColumnBlanksWhitespaceTextPercentCheckSpec
        ]
        if isinstance(_monthly_whitespace_text_percent, Unset):
            monthly_whitespace_text_percent = UNSET
        else:
            monthly_whitespace_text_percent = (
                ColumnBlanksWhitespaceTextPercentCheckSpec.from_dict(
                    _monthly_whitespace_text_percent
                )
            )

        _monthly_null_placeholder_text_percent = d.pop(
            "monthly_null_placeholder_text_percent", UNSET
        )
        monthly_null_placeholder_text_percent: Union[
            Unset, ColumnBlanksNullPlaceholderTextPercentCheckSpec
        ]
        if isinstance(_monthly_null_placeholder_text_percent, Unset):
            monthly_null_placeholder_text_percent = UNSET
        else:
            monthly_null_placeholder_text_percent = (
                ColumnBlanksNullPlaceholderTextPercentCheckSpec.from_dict(
                    _monthly_null_placeholder_text_percent
                )
            )

        column_blanks_monthly_monitoring_checks_spec = cls(
            custom_checks=custom_checks,
            monthly_empty_text_found=monthly_empty_text_found,
            monthly_whitespace_text_found=monthly_whitespace_text_found,
            monthly_null_placeholder_text_found=monthly_null_placeholder_text_found,
            monthly_empty_text_percent=monthly_empty_text_percent,
            monthly_whitespace_text_percent=monthly_whitespace_text_percent,
            monthly_null_placeholder_text_percent=monthly_null_placeholder_text_percent,
        )

        column_blanks_monthly_monitoring_checks_spec.additional_properties = d
        return column_blanks_monthly_monitoring_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_accepted_values_monthly_partitioned_checks_spec import (
        ColumnAcceptedValuesMonthlyPartitionedChecksSpec,
    )
    from ..models.column_anomaly_monthly_partitioned_checks_spec import (
        ColumnAnomalyMonthlyPartitionedChecksSpec,
    )
    from ..models.column_blanks_monthly_partitioned_checks_spec import (
        ColumnBlanksMonthlyPartitionedChecksSpec,
    )
    from ..models.column_bool_monthly_partitioned_checks_spec import (
        ColumnBoolMonthlyPartitionedChecksSpec,
    )
    from ..models.column_custom_sql_monthly_partitioned_checks_spec import (
        ColumnCustomSqlMonthlyPartitionedChecksSpec,
    )
    from ..models.column_datatype_monthly_partitioned_checks_spec import (
        ColumnDatatypeMonthlyPartitionedChecksSpec,
    )
    from ..models.column_datetime_monthly_partitioned_checks_spec import (
        ColumnDatetimeMonthlyPartitionedChecksSpec,
    )
    from ..models.column_integrity_monthly_partitioned_checks_spec import (
        ColumnIntegrityMonthlyPartitionedChecksSpec,
    )
    from ..models.column_monthly_partitioned_check_categories_spec_comparisons import (
        ColumnMonthlyPartitionedCheckCategoriesSpecComparisons,
    )
    from ..models.column_monthly_partitioned_check_categories_spec_custom import (
        ColumnMonthlyPartitionedCheckCategoriesSpecCustom,
    )
    from ..models.column_nulls_monthly_partitioned_checks_spec import (
        ColumnNullsMonthlyPartitionedChecksSpec,
    )
    from ..models.column_numeric_monthly_partitioned_checks_spec import (
        ColumnNumericMonthlyPartitionedChecksSpec,
    )
    from ..models.column_patterns_monthly_partitioned_checks_spec import (
        ColumnPatternsMonthlyPartitionedChecksSpec,
    )
    from ..models.column_pii_monthly_partitioned_checks_spec import (
        ColumnPiiMonthlyPartitionedChecksSpec,
    )
    from ..models.column_text_monthly_partitioned_checks_spec import (
        ColumnTextMonthlyPartitionedChecksSpec,
    )
    from ..models.column_uniqueness_monthly_partitioned_checks_spec import (
        ColumnUniquenessMonthlyPartitionedChecksSpec,
    )


T = TypeVar("T", bound="ColumnMonthlyPartitionedCheckCategoriesSpec")


@_attrs_define
class ColumnMonthlyPartitionedCheckCategoriesSpec:
    """
    Attributes:
        custom (Union[Unset, ColumnMonthlyPartitionedCheckCategoriesSpecCustom]): Dictionary of custom checks. The keys
            are check names within this category.
        nulls (Union[Unset, ColumnNullsMonthlyPartitionedChecksSpec]):
        uniqueness (Union[Unset, ColumnUniquenessMonthlyPartitionedChecksSpec]):
        accepted_values (Union[Unset, ColumnAcceptedValuesMonthlyPartitionedChecksSpec]):
        text (Union[Unset, ColumnTextMonthlyPartitionedChecksSpec]):
        blanks (Union[Unset, ColumnBlanksMonthlyPartitionedChecksSpec]):
        patterns (Union[Unset, ColumnPatternsMonthlyPartitionedChecksSpec]):
        pii (Union[Unset, ColumnPiiMonthlyPartitionedChecksSpec]):
        numeric (Union[Unset, ColumnNumericMonthlyPartitionedChecksSpec]):
        anomaly (Union[Unset, ColumnAnomalyMonthlyPartitionedChecksSpec]):
        datetime_ (Union[Unset, ColumnDatetimeMonthlyPartitionedChecksSpec]):
        bool_ (Union[Unset, ColumnBoolMonthlyPartitionedChecksSpec]):
        integrity (Union[Unset, ColumnIntegrityMonthlyPartitionedChecksSpec]):
        custom_sql (Union[Unset, ColumnCustomSqlMonthlyPartitionedChecksSpec]):
        datatype (Union[Unset, ColumnDatatypeMonthlyPartitionedChecksSpec]):
        comparisons (Union[Unset, ColumnMonthlyPartitionedCheckCategoriesSpecComparisons]): Dictionary of configuration
            of checks for table comparisons at a column level. The key that identifies each comparison must match the name
            of a data comparison that is configured on the parent table.
    """

    custom: Union[Unset, "ColumnMonthlyPartitionedCheckCategoriesSpecCustom"] = UNSET
    nulls: Union[Unset, "ColumnNullsMonthlyPartitionedChecksSpec"] = UNSET
    uniqueness: Union[Unset, "ColumnUniquenessMonthlyPartitionedChecksSpec"] = UNSET
    accepted_values: Union[
        Unset, "ColumnAcceptedValuesMonthlyPartitionedChecksSpec"
    ] = UNSET
    text: Union[Unset, "ColumnTextMonthlyPartitionedChecksSpec"] = UNSET
    blanks: Union[Unset, "ColumnBlanksMonthlyPartitionedChecksSpec"] = UNSET
    patterns: Union[Unset, "ColumnPatternsMonthlyPartitionedChecksSpec"] = UNSET
    pii: Union[Unset, "ColumnPiiMonthlyPartitionedChecksSpec"] = UNSET
    numeric: Union[Unset, "ColumnNumericMonthlyPartitionedChecksSpec"] = UNSET
    anomaly: Union[Unset, "ColumnAnomalyMonthlyPartitionedChecksSpec"] = UNSET
    datetime_: Union[Unset, "ColumnDatetimeMonthlyPartitionedChecksSpec"] = UNSET
    bool_: Union[Unset, "ColumnBoolMonthlyPartitionedChecksSpec"] = UNSET
    integrity: Union[Unset, "ColumnIntegrityMonthlyPartitionedChecksSpec"] = UNSET
    custom_sql: Union[Unset, "ColumnCustomSqlMonthlyPartitionedChecksSpec"] = UNSET
    datatype: Union[Unset, "ColumnDatatypeMonthlyPartitionedChecksSpec"] = UNSET
    comparisons: Union[
        Unset, "ColumnMonthlyPartitionedCheckCategoriesSpecComparisons"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        custom: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom, Unset):
            custom = self.custom.to_dict()

        nulls: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.nulls, Unset):
            nulls = self.nulls.to_dict()

        uniqueness: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.uniqueness, Unset):
            uniqueness = self.uniqueness.to_dict()

        accepted_values: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.accepted_values, Unset):
            accepted_values = self.accepted_values.to_dict()

        text: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.text, Unset):
            text = self.text.to_dict()

        blanks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.blanks, Unset):
            blanks = self.blanks.to_dict()

        patterns: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.patterns, Unset):
            patterns = self.patterns.to_dict()

        pii: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.pii, Unset):
            pii = self.pii.to_dict()

        numeric: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.numeric, Unset):
            numeric = self.numeric.to_dict()

        anomaly: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.anomaly, Unset):
            anomaly = self.anomaly.to_dict()

        datetime_: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.datetime_, Unset):
            datetime_ = self.datetime_.to_dict()

        bool_: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.bool_, Unset):
            bool_ = self.bool_.to_dict()

        integrity: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.integrity, Unset):
            integrity = self.integrity.to_dict()

        custom_sql: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom_sql, Unset):
            custom_sql = self.custom_sql.to_dict()

        datatype: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.datatype, Unset):
            datatype = self.datatype.to_dict()

        comparisons: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.comparisons, Unset):
            comparisons = self.comparisons.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if custom is not UNSET:
            field_dict["custom"] = custom
        if nulls is not UNSET:
            field_dict["nulls"] = nulls
        if uniqueness is not UNSET:
            field_dict["uniqueness"] = uniqueness
        if accepted_values is not UNSET:
            field_dict["accepted_values"] = accepted_values
        if text is not UNSET:
            field_dict["text"] = text
        if blanks is not UNSET:
            field_dict["blanks"] = blanks
        if patterns is not UNSET:
            field_dict["patterns"] = patterns
        if pii is not UNSET:
            field_dict["pii"] = pii
        if numeric is not UNSET:
            field_dict["numeric"] = numeric
        if anomaly is not UNSET:
            field_dict["anomaly"] = anomaly
        if datetime_ is not UNSET:
            field_dict["datetime"] = datetime_
        if bool_ is not UNSET:
            field_dict["bool"] = bool_
        if integrity is not UNSET:
            field_dict["integrity"] = integrity
        if custom_sql is not UNSET:
            field_dict["custom_sql"] = custom_sql
        if datatype is not UNSET:
            field_dict["datatype"] = datatype
        if comparisons is not UNSET:
            field_dict["comparisons"] = comparisons

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_accepted_values_monthly_partitioned_checks_spec import (
            ColumnAcceptedValuesMonthlyPartitionedChecksSpec,
        )
        from ..models.column_anomaly_monthly_partitioned_checks_spec import (
            ColumnAnomalyMonthlyPartitionedChecksSpec,
        )
        from ..models.column_blanks_monthly_partitioned_checks_spec import (
            ColumnBlanksMonthlyPartitionedChecksSpec,
        )
        from ..models.column_bool_monthly_partitioned_checks_spec import (
            ColumnBoolMonthlyPartitionedChecksSpec,
        )
        from ..models.column_custom_sql_monthly_partitioned_checks_spec import (
            ColumnCustomSqlMonthlyPartitionedChecksSpec,
        )
        from ..models.column_datatype_monthly_partitioned_checks_spec import (
            ColumnDatatypeMonthlyPartitionedChecksSpec,
        )
        from ..models.column_datetime_monthly_partitioned_checks_spec import (
            ColumnDatetimeMonthlyPartitionedChecksSpec,
        )
        from ..models.column_integrity_monthly_partitioned_checks_spec import (
            ColumnIntegrityMonthlyPartitionedChecksSpec,
        )
        from ..models.column_monthly_partitioned_check_categories_spec_comparisons import (
            ColumnMonthlyPartitionedCheckCategoriesSpecComparisons,
        )
        from ..models.column_monthly_partitioned_check_categories_spec_custom import (
            ColumnMonthlyPartitionedCheckCategoriesSpecCustom,
        )
        from ..models.column_nulls_monthly_partitioned_checks_spec import (
            ColumnNullsMonthlyPartitionedChecksSpec,
        )
        from ..models.column_numeric_monthly_partitioned_checks_spec import (
            ColumnNumericMonthlyPartitionedChecksSpec,
        )
        from ..models.column_patterns_monthly_partitioned_checks_spec import (
            ColumnPatternsMonthlyPartitionedChecksSpec,
        )
        from ..models.column_pii_monthly_partitioned_checks_spec import (
            ColumnPiiMonthlyPartitionedChecksSpec,
        )
        from ..models.column_text_monthly_partitioned_checks_spec import (
            ColumnTextMonthlyPartitionedChecksSpec,
        )
        from ..models.column_uniqueness_monthly_partitioned_checks_spec import (
            ColumnUniquenessMonthlyPartitionedChecksSpec,
        )

        d = src_dict.copy()
        _custom = d.pop("custom", UNSET)
        custom: Union[Unset, ColumnMonthlyPartitionedCheckCategoriesSpecCustom]
        if isinstance(_custom, Unset):
            custom = UNSET
        else:
            custom = ColumnMonthlyPartitionedCheckCategoriesSpecCustom.from_dict(
                _custom
            )

        _nulls = d.pop("nulls", UNSET)
        nulls: Union[Unset, ColumnNullsMonthlyPartitionedChecksSpec]
        if isinstance(_nulls, Unset):
            nulls = UNSET
        else:
            nulls = ColumnNullsMonthlyPartitionedChecksSpec.from_dict(_nulls)

        _uniqueness = d.pop("uniqueness", UNSET)
        uniqueness: Union[Unset, ColumnUniquenessMonthlyPartitionedChecksSpec]
        if isinstance(_uniqueness, Unset):
            uniqueness = UNSET
        else:
            uniqueness = ColumnUniquenessMonthlyPartitionedChecksSpec.from_dict(
                _uniqueness
            )

        _accepted_values = d.pop("accepted_values", UNSET)
        accepted_values: Union[Unset, ColumnAcceptedValuesMonthlyPartitionedChecksSpec]
        if isinstance(_accepted_values, Unset):
            accepted_values = UNSET
        else:
            accepted_values = (
                ColumnAcceptedValuesMonthlyPartitionedChecksSpec.from_dict(
                    _accepted_values
                )
            )

        _text = d.pop("text", UNSET)
        text: Union[Unset, ColumnTextMonthlyPartitionedChecksSpec]
        if isinstance(_text, Unset):
            text = UNSET
        else:
            text = ColumnTextMonthlyPartitionedChecksSpec.from_dict(_text)

        _blanks = d.pop("blanks", UNSET)
        blanks: Union[Unset, ColumnBlanksMonthlyPartitionedChecksSpec]
        if isinstance(_blanks, Unset):
            blanks = UNSET
        else:
            blanks = ColumnBlanksMonthlyPartitionedChecksSpec.from_dict(_blanks)

        _patterns = d.pop("patterns", UNSET)
        patterns: Union[Unset, ColumnPatternsMonthlyPartitionedChecksSpec]
        if isinstance(_patterns, Unset):
            patterns = UNSET
        else:
            patterns = ColumnPatternsMonthlyPartitionedChecksSpec.from_dict(_patterns)

        _pii = d.pop("pii", UNSET)
        pii: Union[Unset, ColumnPiiMonthlyPartitionedChecksSpec]
        if isinstance(_pii, Unset):
            pii = UNSET
        else:
            pii = ColumnPiiMonthlyPartitionedChecksSpec.from_dict(_pii)

        _numeric = d.pop("numeric", UNSET)
        numeric: Union[Unset, ColumnNumericMonthlyPartitionedChecksSpec]
        if isinstance(_numeric, Unset):
            numeric = UNSET
        else:
            numeric = ColumnNumericMonthlyPartitionedChecksSpec.from_dict(_numeric)

        _anomaly = d.pop("anomaly", UNSET)
        anomaly: Union[Unset, ColumnAnomalyMonthlyPartitionedChecksSpec]
        if isinstance(_anomaly, Unset):
            anomaly = UNSET
        else:
            anomaly = ColumnAnomalyMonthlyPartitionedChecksSpec.from_dict(_anomaly)

        _datetime_ = d.pop("datetime", UNSET)
        datetime_: Union[Unset, ColumnDatetimeMonthlyPartitionedChecksSpec]
        if isinstance(_datetime_, Unset):
            datetime_ = UNSET
        else:
            datetime_ = ColumnDatetimeMonthlyPartitionedChecksSpec.from_dict(_datetime_)

        _bool_ = d.pop("bool", UNSET)
        bool_: Union[Unset, ColumnBoolMonthlyPartitionedChecksSpec]
        if isinstance(_bool_, Unset):
            bool_ = UNSET
        else:
            bool_ = ColumnBoolMonthlyPartitionedChecksSpec.from_dict(_bool_)

        _integrity = d.pop("integrity", UNSET)
        integrity: Union[Unset, ColumnIntegrityMonthlyPartitionedChecksSpec]
        if isinstance(_integrity, Unset):
            integrity = UNSET
        else:
            integrity = ColumnIntegrityMonthlyPartitionedChecksSpec.from_dict(
                _integrity
            )

        _custom_sql = d.pop("custom_sql", UNSET)
        custom_sql: Union[Unset, ColumnCustomSqlMonthlyPartitionedChecksSpec]
        if isinstance(_custom_sql, Unset):
            custom_sql = UNSET
        else:
            custom_sql = ColumnCustomSqlMonthlyPartitionedChecksSpec.from_dict(
                _custom_sql
            )

        _datatype = d.pop("datatype", UNSET)
        datatype: Union[Unset, ColumnDatatypeMonthlyPartitionedChecksSpec]
        if isinstance(_datatype, Unset):
            datatype = UNSET
        else:
            datatype = ColumnDatatypeMonthlyPartitionedChecksSpec.from_dict(_datatype)

        _comparisons = d.pop("comparisons", UNSET)
        comparisons: Union[
            Unset, ColumnMonthlyPartitionedCheckCategoriesSpecComparisons
        ]
        if isinstance(_comparisons, Unset):
            comparisons = UNSET
        else:
            comparisons = (
                ColumnMonthlyPartitionedCheckCategoriesSpecComparisons.from_dict(
                    _comparisons
                )
            )

        column_monthly_partitioned_check_categories_spec = cls(
            custom=custom,
            nulls=nulls,
            uniqueness=uniqueness,
            accepted_values=accepted_values,
            text=text,
            blanks=blanks,
            patterns=patterns,
            pii=pii,
            numeric=numeric,
            anomaly=anomaly,
            datetime_=datetime_,
            bool_=bool_,
            integrity=integrity,
            custom_sql=custom_sql,
            datatype=datatype,
            comparisons=comparisons,
        )

        column_monthly_partitioned_check_categories_spec.additional_properties = d
        return column_monthly_partitioned_check_categories_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_anomaly_monthly_monitoring_checks_spec_custom_checks import (
        ColumnAnomalyMonthlyMonitoringChecksSpecCustomChecks,
    )
    from ..models.column_mean_change_check_spec import ColumnMeanChangeCheckSpec
    from ..models.column_median_change_check_spec import ColumnMedianChangeCheckSpec
    from ..models.column_sum_change_check_spec import ColumnSumChangeCheckSpec


T = TypeVar("T", bound="ColumnAnomalyMonthlyMonitoringChecksSpec")


@_attrs_define
class ColumnAnomalyMonthlyMonitoringChecksSpec:
    """
    Attributes:
        custom_checks (Union[Unset, ColumnAnomalyMonthlyMonitoringChecksSpecCustomChecks]): Dictionary of additional
            custom checks within this category. The keys are check names defined in the definition section. The sensor
            parameters and rules should match the type of the configured sensor and rule for the custom check.
        monthly_sum_change (Union[Unset, ColumnSumChangeCheckSpec]):
        monthly_mean_change (Union[Unset, ColumnMeanChangeCheckSpec]):
        monthly_median_change (Union[Unset, ColumnMedianChangeCheckSpec]):
    """

    custom_checks: Union[
        Unset, "ColumnAnomalyMonthlyMonitoringChecksSpecCustomChecks"
    ] = UNSET
    monthly_sum_change: Union[Unset, "ColumnSumChangeCheckSpec"] = UNSET
    monthly_mean_change: Union[Unset, "ColumnMeanChangeCheckSpec"] = UNSET
    monthly_median_change: Union[Unset, "ColumnMedianChangeCheckSpec"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        custom_checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom_checks, Unset):
            custom_checks = self.custom_checks.to_dict()

        monthly_sum_change: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_sum_change, Unset):
            monthly_sum_change = self.monthly_sum_change.to_dict()

        monthly_mean_change: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_mean_change, Unset):
            monthly_mean_change = self.monthly_mean_change.to_dict()

        monthly_median_change: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_median_change, Unset):
            monthly_median_change = self.monthly_median_change.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if custom_checks is not UNSET:
            field_dict["custom_checks"] = custom_checks
        if monthly_sum_change is not UNSET:
            field_dict["monthly_sum_change"] = monthly_sum_change
        if monthly_mean_change is not UNSET:
            field_dict["monthly_mean_change"] = monthly_mean_change
        if monthly_median_change is not UNSET:
            field_dict["monthly_median_change"] = monthly_median_change

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_anomaly_monthly_monitoring_checks_spec_custom_checks import (
            ColumnAnomalyMonthlyMonitoringChecksSpecCustomChecks,
        )
        from ..models.column_mean_change_check_spec import ColumnMeanChangeCheckSpec
        from ..models.column_median_change_check_spec import ColumnMedianChangeCheckSpec
        from ..models.column_sum_change_check_spec import ColumnSumChangeCheckSpec

        d = src_dict.copy()
        _custom_checks = d.pop("custom_checks", UNSET)
        custom_checks: Union[
            Unset, ColumnAnomalyMonthlyMonitoringChecksSpecCustomChecks
        ]
        if isinstance(_custom_checks, Unset):
            custom_checks = UNSET
        else:
            custom_checks = (
                ColumnAnomalyMonthlyMonitoringChecksSpecCustomChecks.from_dict(
                    _custom_checks
                )
            )

        _monthly_sum_change = d.pop("monthly_sum_change", UNSET)
        monthly_sum_change: Union[Unset, ColumnSumChangeCheckSpec]
        if isinstance(_monthly_sum_change, Unset):
            monthly_sum_change = UNSET
        else:
            monthly_sum_change = ColumnSumChangeCheckSpec.from_dict(_monthly_sum_change)

        _monthly_mean_change = d.pop("monthly_mean_change", UNSET)
        monthly_mean_change: Union[Unset, ColumnMeanChangeCheckSpec]
        if isinstance(_monthly_mean_change, Unset):
            monthly_mean_change = UNSET
        else:
            monthly_mean_change = ColumnMeanChangeCheckSpec.from_dict(
                _monthly_mean_change
            )

        _monthly_median_change = d.pop("monthly_median_change", UNSET)
        monthly_median_change: Union[Unset, ColumnMedianChangeCheckSpec]
        if isinstance(_monthly_median_change, Unset):
            monthly_median_change = UNSET
        else:
            monthly_median_change = ColumnMedianChangeCheckSpec.from_dict(
                _monthly_median_change
            )

        column_anomaly_monthly_monitoring_checks_spec = cls(
            custom_checks=custom_checks,
            monthly_sum_change=monthly_sum_change,
            monthly_mean_change=monthly_mean_change,
            monthly_median_change=monthly_median_change,
        )

        column_anomaly_monthly_monitoring_checks_spec.additional_properties = d
        return column_anomaly_monthly_monitoring_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
